'use strict';

var lr = require('@lezer/lr');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');
var autocomplete = require('@codemirror/autocomplete');

// Note that 'eval' and 'do' are not in this list as they can accept a block.
const namedUnaryOperators = [
    'abs',
    'alarm',
    'await',
    'caller',
    'chdir',
    'chr',
    'chroot',
    'close',
    'closedir',
    'cos',
    'defined',
    'delete',
    'eof',
    'evalbytes',
    'exists',
    'exit',
    'exp',
    'fileno',
    'getc',
    'gethostbyname',
    'getnetbyname',
    'getpgrp',
    'getprotobyname',
    'glob',
    'gmtime',
    'hex',
    'int',
    'lc',
    'lcfirst',
    'length',
    'localtime',
    'lock',
    'log',
    'lstat',
    'oct',
    'ord',
    'pos',
    'quotemeta',
    'rand',
    'readdir',
    'readline',
    'readlink',
    'readpipe',
    'reset',
    'rewinddir',
    'ref',
    'rmdir',
    'scalar',
    'select',
    'sin',
    'sleep',
    'sqrt',
    'srand',
    'stat',
    'tell',
    'telldir',
    'tied',
    'uc',
    'ucfirst',
    'umask',
    'undef',
    'untie'
];
// The list operators that can operate on a block (grep, map, join, sort, and unpack) are handled separately.
const listOperators = [
    'atan2',
    'chomp',
    'chop',
    'chmod',
    'chown',
    'crypt',
    'die',
    'fcntl',
    'flock',
    'getpriority',
    'index',
    'ioctl',
    'kill',
    'link',
    'mkdir',
    'open',
    'opendir',
    'pack',
    'pipe',
    'read',
    'rename',
    'reverse',
    'rindex',
    'seek',
    'seekdir',
    'setpgrp',
    'setpriority',
    'split',
    'sprintf',
    'substr',
    'symlink',
    'syscall',
    'sysopen',
    'sysread',
    'sysseek',
    'syswrite',
    'tie',
    'truncate',
    'unlink',
    'utime',
    'vec',
    'waitpid',
    'warn'
];

// This file was generated by lezer-generator. You probably shouldn't edit it.
const automaticSemicolon = 308, statementEnd = 309, UnrestrictedIdentifier = 1, SpecialScalarVariable = 2, NamedUnaryOperator = 3, ListOperator = 4, FileTestOp = 5, IOOperatorStart = 6, Glob = 7, ReadonlySTDIN = 8, IOOperatorEnd = 9, HeredocStartIdentifier = 10, uninterpolatedHeredocStart = 310, interpolatedHeredocStart = 311, HeredocEndIdentifier = 11, InterpolatedStringContent = 12, EscapeSequence = 13, afterInterpolation = 312, packageNamePart = 313, afterPackageName = 314, QuoteLikeStartDelimiter = 14, QuoteLikeSeparatorDelimiter = 15, QuoteLikeEndDelimiter = 16, StringContent = 17, QWElement = 18, patternMatchStart = 315, RegexOptions = 19, regexEnd = 316, PodDirective = 20, PodContent = 21, PodCut = 22, endDataBlock = 317, q = 42, qq = 45, qw = 71, qx = 82, m = 84, qr = 88, s = 90, tr = 92, y = 93, Prototype = 111, PackageName = 121;

const isUpperCaseASCIILetter = (ch) => ch >= 65 && ch <= 90;
const isLowerCaseASCIILetter = (ch) => ch >= 97 && ch <= 122;
const isASCIILetter = (ch) => isLowerCaseASCIILetter(ch) || isUpperCaseASCIILetter(ch);
const isDigit = (ch) => ch >= 48 && ch <= 55;
const isIdentifierChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch) || isDigit(ch);
const isVariableStartChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch);
const isRegexOptionChar = (ch, regexType) => {
    if (regexType === tr || regexType === y) {
        if (ch == 99 /* c */ || ch == 100 /* d */ || ch == 115 /* s */ || ch == 114 /* r */)
            return true;
        return false;
    }
    if (ch == 109 /* m */ ||
        ch == 115 /* s */ ||
        ch == 105 /* i */ ||
        ch == 120 /* x */ ||
        ch == 112 /* p */ ||
        ch == 111 /* o */ ||
        ch == 100 /* d */ ||
        ch == 117 /* u */ ||
        ch == 97 /* a */ ||
        ch == 108 /* l */ ||
        ch == 110 /* n */)
        return true;
    if ((regexType === m || regexType === s) && (ch == 103 /* g */ || ch == 99) /* c */)
        return true;
    if (regexType == s && (ch == 101 /* e */ || ch == 114) /* r */)
        return true;
    return false;
};
// !"$%&'()*+,-./0123456789:;<=>?@[\]`~
// For arrays this is only used for interpolation and in that case only @$, @+, @-, and @1 .. @9 are allowed.
const isSpecialVariableChar = (ch, arrayType = false) => arrayType
    ? ch == 36 || ch == 43 || ch == 45 || (ch >= 49 && ch <= 57)
    : (ch >= 33 && ch != 35 && ch <= 64) || ch == 91 || ch == 92 || ch == 93 || ch == 96 || ch == 126;
/* 0-9, a-f, A-F */
const isHex = (ch) => (ch >= 48 && ch <= 55) || (ch >= 97 && ch <= 102) || (ch >= 65 && ch <= 70);
// ' ', \t, \n, \r
const isWhitespace = (ch) => ch == 32 || ch == 9 || ch == 10 || ch == 13;
const gobbleWhitespace = (input) => {
    while (isWhitespace(input.next))
        input.advance();
};
// rwxoRWXOezsfdlpSbctugkTBMAC
const isFileTestOperatorChar = (ch) => ch == 114 ||
    ch == 119 ||
    ch == 120 ||
    ch == 111 ||
    ch == 82 ||
    ch == 87 ||
    ch == 88 ||
    ch == 79 ||
    ch == 101 ||
    ch == 122 ||
    ch == 115 ||
    ch == 102 ||
    ch == 100 ||
    ch == 108 ||
    ch == 112 ||
    ch == 83 ||
    ch == 98 ||
    ch == 99 ||
    ch == 116 ||
    ch == 117 ||
    ch == 103 ||
    ch == 107 ||
    ch == 84 ||
    ch == 66 ||
    ch == 77 ||
    ch == 65 ||
    ch == 67;
const heredocQueue = [];
// Base class that all tracker contexts extend.
class Context {
    type;
    parent;
    stackPos;
    // Used by quote and quoteLike operators.
    startDelimiter;
    endDelimiter;
    // Used by quoteLike operators.
    quoteLikeType;
    nestLevel = 0;
    // Used by heredocs.
    tag;
    indented = false;
    inBody = false;
    newlinePos;
    // Used by any interpolating context.
    interpolating = false;
    constructor(type, parent = null, stackPos = -1, options = {}) {
        this.type = type;
        this.parent = parent;
        this.stackPos = stackPos;
        this.quoteLikeType = options.quoteLikeType;
        this.interpolating = options.interpolating ?? true;
        this.indented = options.indented ?? false;
        if (options.tag)
            this.tag = options.tag;
        if (typeof options.startDelimiter === 'number')
            this.setStartAndEndDelimiters(options.startDelimiter);
        if (typeof options.newlinePos === 'number')
            this.newlinePos = options.newlinePos;
    }
    setStartAndEndDelimiters(start) {
        this.startDelimiter = start;
        if (start == 40 /* ( */) {
            this.endDelimiter = 41 /* ) */;
        }
        else if (start == 60 /* < */) {
            this.endDelimiter = 62 /* > */;
        }
        else if (start == 91 /* [ */) {
            this.endDelimiter = 93 /* ] */;
        }
        else if (start == 123 /* { */) {
            this.endDelimiter = 125 /* } */;
        }
        else
            this.endDelimiter = start;
    }
    atEnd(input) {
        if (this.type === 'heredoc') {
            if (!this.tag || input.peek(-1) !== 10)
                return false;
            let pos = 0;
            if (this.indented) {
                let nextChar = input.peek(pos);
                while (isWhitespace(nextChar))
                    nextChar = input.peek(++pos);
            }
            for (const tagCh of this.tag) {
                if (input.peek(pos++) !== tagCh)
                    return false;
            }
            if (input.peek(pos) < 0 || input.peek(pos) == 10)
                return pos;
            return false;
        }
        else {
            return input.next === this.endDelimiter ? 1 : false;
        }
    }
}
const contextTracker = new lr.ContextTracker({
    start: new Context('root'),
    shift(context, term, stack, input) {
        if (term === q || term === qq || term === qx || term === qw) {
            return new Context('quoteLike', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === m || term === qr || term === s || term === tr || term === y) {
            return new Context('quoteLike&regex', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === IOOperatorStart) {
            return new Context('iooperator', context);
        }
        else if (term === HeredocStartIdentifier) {
            let pos = 0;
            const indented = input.next == 126; /* ~ */
            if (indented)
                ++pos;
            let haveWhitespace = false;
            while (isWhitespace(input.peek(pos))) {
                haveWhitespace = true;
                ++pos;
            }
            const quote = input.peek(pos) == 39 /* ' */ || input.peek(pos) == 34 /* " */ || input.peek(pos) == 96 /* ` */
                ? input.peek(pos)
                : undefined;
            if (!quote && haveWhitespace)
                return context;
            if (quote)
                ++pos;
            const backslashedTag = !quote && input.peek(pos) == 92; /* \\ */
            if (backslashedTag && (haveWhitespace || isWhitespace(input.peek(++pos))))
                return context;
            if (!isIdentifierChar(input.peek(pos)))
                return context;
            const tag = [input.peek(pos++)];
            for (;;) {
                const next = input.peek(pos++);
                if (!isIdentifierChar(next))
                    break;
                tag.push(next);
            }
            if (heredocQueue[0]?.stackPos !== stack.pos) {
                while (input.peek(pos) != 10 /* \n */ && input.peek(pos) >= 0)
                    ++pos;
                heredocQueue.unshift(new Context('heredoc', context, stack.pos, {
                    tag,
                    interpolating: (!quote || quote == 34 || quote == 96) && !backslashedTag,
                    indented,
                    newlinePos: input.pos + pos
                }));
            }
            return context;
        }
        else if (term === patternMatchStart) {
            if (input.next == 47 /* / */)
                return new Context('regex', context, stack.pos, { startDelimiter: 47, quoteLikeType: m });
        }
        else if ((context.type !== 'quote' || input.next != context.endDelimiter) &&
            term !== InterpolatedStringContent) {
            if (input.next == 34 /* " */ || input.next == 96 /* ` */) {
                return new Context('quote', context, stack.pos, { startDelimiter: input.next });
            }
        }
        if (context.type.startsWith('quoteLike') && term === QuoteLikeStartDelimiter) {
            let pos = 1;
            let startDelimiter = input.next;
            while (isWhitespace(startDelimiter))
                startDelimiter = input.peek(pos++);
            if (startDelimiter >= 0) {
                context.setStartAndEndDelimiters(startDelimiter);
                // Note that q and qw are not interpolated, but don't need to set this because they can't accept
                // interpolated content.
                if (context.quoteLikeType === tr ||
                    context.quoteLikeType === y ||
                    ((context.quoteLikeType === m ||
                        context.quoteLikeType === qr ||
                        context.quoteLikeType === qx ||
                        context.quoteLikeType === s) &&
                        startDelimiter == 39) /* ' */)
                    context.interpolating = false;
                return context;
            }
        }
        if ((term === interpolatedHeredocStart || term === uninterpolatedHeredocStart) &&
            heredocQueue.slice(-1)[0]?.newlinePos !== context.newlinePos) {
            const heredocContext = heredocQueue.pop();
            if (heredocContext) {
                heredocContext.parent = context;
                heredocContext.inBody = true;
                return heredocContext;
            }
        }
        if (context.parent &&
            ((context.type === 'quote' && input.next === context.endDelimiter) ||
                (context.type === 'quoteLike' && term === QuoteLikeEndDelimiter) ||
                (context.type === 'regex' && term === regexEnd) ||
                (context.type === 'quoteLike&regex' && term === regexEnd) ||
                (context.type === 'heredoc' && term === HeredocEndIdentifier) ||
                (context.type === 'iooperator' && term === IOOperatorEnd))) {
            return context.parent;
        }
        return context;
    },
    strict: false
});
const semicolon = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(statementEnd) &&
        !heredocQueue.length &&
        (input.peek(-1) == 59 /* ; */ ||
            (input.peek(-1) != 59 /* ; */ && (input.next < 0 || input.next == 10))) /* \n */) {
        input.acceptToken(statementEnd, 0);
    }
    else if (stack.canShift(automaticSemicolon) &&
        input.next != 59 /* ; */ &&
        (input.next < 0 || input.next == 125) /* } */)
        input.acceptToken(automaticSemicolon);
});
const unrestrictedIdentifier = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(UnrestrictedIdentifier)) {
        gobbleWhitespace(input);
        if (input.next < 0 || isASCIILetter(input.next) || input.next == 95 /* _ */)
            return;
        while (input.next >= 0 && isIdentifierChar(input.next))
            input.advance();
        input.acceptToken(UnrestrictedIdentifier);
    }
});
// Note that is only to pick up special variables that won't be considered as a ScalarVariable already.
const specialScalarVariable = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(SpecialScalarVariable) && input.next == 36 /* $ */) {
        if (stack.canShift(Prototype))
            return;
        const first = input.peek(1);
        const second = input.peek(2);
        if (first == 123 /* { */ && isSpecialVariableChar(second) && input.peek(3) == 125 /* } */) {
            input.acceptToken(SpecialScalarVariable, 4);
            return;
        }
        if (first == 123 /* { */ && second == 94 /* ^ */) {
            let pos = 3, ch;
            while ((isUpperCaseASCIILetter((ch = input.peek(pos))) || ch == 95) /* _ */ && ch != 125 /* } */)
                ++pos;
            if (ch == 125) {
                input.acceptToken(SpecialScalarVariable, pos + 1);
                return;
            }
        }
        if (first == 94 /* ^ */ && (isUpperCaseASCIILetter(second) || second == 95) /* _ */) {
            input.acceptToken(SpecialScalarVariable, 3);
            return;
        }
        if (!isSpecialVariableChar(first))
            return;
        if (first == 36 /* $ */ && isIdentifierChar(second))
            return;
        input.acceptToken(SpecialScalarVariable, 2);
        return;
    }
});
// Finds the longest lower case word coming up in the stream.  Returns an array
// containing the word and the ascii character code of the next character after it.
const peekLCWord = (input) => {
    let pos = 0;
    let word = '', nextChar;
    while (isLowerCaseASCIILetter((nextChar = input.peek(pos)))) {
        ++pos;
        word += String.fromCharCode(nextChar);
    }
    return [word, nextChar];
};
const builtinOperator = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(NamedUnaryOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (namedUnaryOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(NamedUnaryOperator, word.length);
    }
    if (stack.canShift(ListOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (listOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(ListOperator, word.length);
    }
});
const fileIO = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(FileTestOp) && !stack.canShift(PackageName)) {
        gobbleWhitespace(input);
        if (input.next == 45 /* - */ && isFileTestOperatorChar(input.peek(1)) && !isASCIILetter(input.peek(2)))
            input.acceptToken(FileTestOp, 2);
    }
    // Start an IO operator if the following input contains a '<' character that is not followed by another
    // one or the following input specifically contains <<>>.
    if (stack.canShift(IOOperatorStart) &&
        input.next == 60 &&
        (input.peek(1) != 60 || (input.peek(2) == 62 && input.peek(3) == 62))) {
        input.acceptToken(IOOperatorStart, 1);
        return;
    }
    if (!(stack.context instanceof Context) || stack.context.type !== 'iooperator')
        return;
    // End the IO operator when the '>' character is encountered.
    if (stack.canShift(IOOperatorEnd) && input.next == 62) {
        input.acceptToken(IOOperatorEnd, 1);
        return;
    }
    // In this case the initial '<' started the IO operator, and what follows is '<>>'
    // to finish the read only standard input declaration.
    if (input.peek(0) == 60 && input.peek(1) == 62 && input.peek(2) == 62) {
        input.acceptToken(ReadonlySTDIN, 2);
        return;
    }
    let pos = 0, ch;
    const isPossibleVariable = input.next == 36; /* $ */
    if (isPossibleVariable)
        ++pos;
    let haveWhitespace = false, haveNonASCII = false;
    while ((ch = input.peek(pos)) >= 0 && ch != 62 /* > */) {
        if (isWhitespace(ch))
            haveWhitespace = true;
        if (!isASCIILetter(ch))
            haveNonASCII = true;
        ++pos;
    }
    if ((isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        (!isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        ch < 0)
        return;
    input.acceptToken(Glob, pos);
}, { contextual: true });
const heredoc = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(HeredocStartIdentifier)) {
        const indented = input.next == 126; /* ~ */
        if (indented)
            input.advance();
        gobbleWhitespace(input);
        const quote = input.next == 39 /* ' */ || input.next == 34 /* " */ || input.next == 96 /* ` */
            ? input.next
            : undefined;
        if (!quote && isWhitespace(input.peek(-1)))
            return;
        if (quote)
            input.advance();
        if (input.next == 92 /* \\ */ && (isWhitespace(input.peek(-1)) || isWhitespace(input.advance())))
            return;
        if (!isIdentifierChar(input.next))
            return;
        for (;;) {
            input.advance();
            if (!isIdentifierChar(input.next))
                break;
        }
        if (quote) {
            if (input.next != quote)
                return;
            input.advance();
        }
        input.acceptToken(HeredocStartIdentifier);
        return;
    }
    if (!(stack.context instanceof Context))
        return;
    if (input.next == 10 /* \n */ &&
        heredocQueue.length &&
        heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos &&
        (stack.canShift(uninterpolatedHeredocStart) || stack.canShift(interpolatedHeredocStart))) {
        if (heredocQueue.slice(-1)[0]?.interpolating)
            input.acceptToken(interpolatedHeredocStart, 1);
        else
            input.acceptToken(uninterpolatedHeredocStart, 1);
        return;
    }
    if (stack.context.type !== 'heredoc' || !stack.context.inBody)
        return;
    if (stack.context.interpolating) {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        else if (input.next < 0) {
            input.acceptToken(HeredocEndIdentifier);
            return;
        }
    }
    else {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        for (;;) {
            if (input.next < 0) {
                input.acceptToken(HeredocEndIdentifier);
                return;
            }
            if (input.next != 10 /* \n */) {
                input.advance();
                continue;
            }
            input.advance();
            const endCount = stack.context.atEnd(input);
            if (endCount) {
                input.acceptToken(StringContent);
                return;
            }
            input.advance();
        }
    }
}, { contextual: true });
const scanEscape = (input) => {
    const after = input.peek(1);
    // Restricted range octal character
    if (after >= 48 && after <= 55 /* 0-7 */) {
        let size = 2, next;
        while (size < 5 && (next = input.peek(size)) >= 48 && next <= 55)
            ++size;
        return size;
    }
    // Restricted range hexidecimal character
    if (after == 120 /* x */ && isHex(input.peek(2)))
        return isHex(input.peek(3)) ? 4 : 3;
    // Hexidecimal character
    if (after == 120 /* x */ && input.peek(2) == 123 /* { */) {
        // FIXME: There could be optional blanks at the beginning and end inside the braces.
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (!isHex(next))
                break;
        }
    }
    // This could be any named unicode character or character sequence.
    if (after == 78 /* N */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 0)
                break;
        }
    }
    // Octal character
    if (after == 111 /* o */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 48 || next > 55 /* not 0-7 */)
                break;
        }
    }
    return 2;
};
const interpolated = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.interpolating)
        return;
    let content = false;
    for (;; content = true) {
        if (heredocQueue.length &&
            (stack.context.type !== 'heredoc' ||
                heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos) &&
            input.next == 10 /* \n */) {
            break;
        }
        if ((stack.context.nestLevel == 0 && stack.context.atEnd(input)) ||
            input.next < 0 ||
            ((input.next == 36 /* $ */ || input.next == 64) /* @ */ &&
                (isVariableStartChar(input.peek(1)) ||
                    input.peek(1) == 123 /* { */ ||
                    (isSpecialVariableChar(input.peek(1), input.next == 64 /* @ */) &&
                        (stack.context.nestLevel > 0 || input.peek(1) !== stack.context.endDelimiter))))) {
            break;
        }
        if (stack.context.type.startsWith('quoteLike') &&
            stack.context.startDelimiter !== stack.context.endDelimiter &&
            input.next === stack.context.startDelimiter) {
            ++stack.context.nestLevel;
        }
        else if (stack.context.nestLevel > 0 && input.next === stack.context.endDelimiter) {
            --stack.context.nestLevel;
        }
        else if (input.next == 92 /* \\ */) {
            const escaped = scanEscape(input);
            if (escaped) {
                if (content)
                    break;
                else {
                    input.acceptToken(EscapeSequence, escaped);
                    return;
                }
            }
        }
        else if (!content &&
            (input.next == 91 /* [ */ ||
                input.next == 123 /* { */ ||
                (input.next == 45 /* - */ &&
                    input.peek(1) == 62 /* > */ &&
                    (input.peek(2) == 91 /* [ */ || input.peek(2) == 123))) /* { */ &&
            stack.canShift(afterInterpolation)) {
            input.acceptToken(afterInterpolation);
            return;
        }
        else if (!content &&
            input.next == 58 /* : */ &&
            input.peek(1) == 58 &&
            (stack.canShift(packageNamePart) || stack.canShift(afterPackageName))) {
            let pos = 2, ch;
            while (isIdentifierChar((ch = input.peek(pos))))
                ++pos;
            if (ch == 58 && input.peek(pos + 1) == 58)
                input.acceptToken(packageNamePart);
            else
                input.acceptToken(afterPackageName);
            return;
        }
        input.advance();
    }
    if (content)
        input.acceptToken(InterpolatedStringContent);
}, { contextual: true });
// Note that the paired delimiters enabled by the extra_paired_delimiters
// feature are not dealt with by the quote-like tokenizers.
const quoteLikeOperator = new lr.ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.type.startsWith('quoteLike'))
        return;
    if (!stack.context.startDelimiter) {
        const haveWhitespace = isWhitespace(input.next);
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (stack.canShift(QuoteLikeStartDelimiter) && nextChar >= 0 && (!haveWhitespace || nextChar !== 35)) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
        return;
    }
    if (stack.canShift(QWElement) && isWhitespace(input.next))
        gobbleWhitespace(input);
    if (stack.canShift(QuoteLikeSeparatorDelimiter) &&
        stack.context.startDelimiter === stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeSeparatorDelimiter, 1);
        return;
    }
    else if (stack.canShift(QuoteLikeEndDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (stack.canShift(QuoteLikeStartDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter) {
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (nextChar === stack.context.startDelimiter) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
    }
    if (input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (input.next >= 0) {
        if (stack.canShift(StringContent)) {
            while (input.next >= 0 &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(StringContent);
            return;
        }
        else if (stack.canShift(QWElement)) {
            while (input.next >= 0 &&
                !isWhitespace(input.next) &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(QWElement);
            return;
        }
    }
}, { contextual: true });
const regex = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(patternMatchStart) && input.next == 47 /* / */) {
        const divisionToken = stack.parser.nodeSet.types.find((t) => t.name == '/')?.id;
        if (typeof divisionToken === 'number' && !stack.canShift(divisionToken))
            input.acceptToken(patternMatchStart);
    }
    if (!(stack.context instanceof Context) || !stack.context.type.endsWith('regex'))
        return;
    if (stack.canShift(RegexOptions) &&
        stack.context.quoteLikeType &&
        isRegexOptionChar(input.next, stack.context.quoteLikeType)) {
        while (input.next >= 0 && isRegexOptionChar(input.next, stack.context.quoteLikeType))
            input.advance();
        input.acceptToken(RegexOptions);
        return;
    }
    if (stack.canShift(regexEnd)) {
        input.acceptToken(regexEnd);
        return;
    }
}, { contextual: true });
const pod = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(PodDirective)) {
        if ((input.peek(-1) == 10 /* \n */ || input.peek(-1) < 0) &&
            input.next == 61 /* = */ &&
            isASCIILetter(input.peek(1))) {
            while (input.next >= 0 && input.next != 10)
                input.advance();
            input.acceptToken(PodDirective);
            return;
        }
    }
    if (stack.canShift(PodContent)) {
        while (input.next >= 0) {
            if (input.next != 10) {
                input.advance();
                continue;
            }
            input.advance();
            if (input.peek(0) == 61 /* = */ &&
                input.peek(1) == 99 /* c */ &&
                input.peek(2) == 117 /* u */ &&
                input.peek(3) == 116 /* t */ &&
                (input.peek(4) == 10 || input.peek(4) < 0))
                break;
        }
        input.acceptToken(PodContent);
        return;
    }
    if (stack.canShift(PodCut)) {
        if ((input.peek(-1) == 10 || input.peek(-1) < 0) &&
            input.peek(0) == 61 /* = */ &&
            input.peek(1) == 99 /* c */ &&
            input.peek(2) == 117 /* u */ &&
            input.peek(3) == 116 /* t */ &&
            (input.peek(4) == 10 || input.peek(4) < 0)) {
            input.acceptToken(PodCut, 4);
            return;
        }
    }
});
const endData = new lr.ExternalTokenizer((input, stack) => {
    if (stack.canShift(endDataBlock)) {
        while (input.advance() >= 0)
            ;
        input.acceptToken(endDataBlock);
    }
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_Identifier = {__proto__:null,q:85, qq:91, __FILE__:121, __LINE__:123, __PACKAGE__:125, __SUB__:127, qw:143, qx:165, m:169, qr:177, s:181, tr:185, y:187, our:209, state:211, my:213, local:215, sub:219, prototype:235, package:241, use:253, no:255, if:263, lib:267, subs:271, feature:275, require:281, constant:285, parent:289, base:291, async:299, return:307, unless:309, while:311, until:313, for:315, foreach:317, elsif:323, else:327, continue:337, BEGIN:355, UNITCHECK:357, CHECK:359, INIT:361, END:363, __END__:373, __DATA__:375, next:379, last:381, redo:383, x:393, lt:407, gt:409, le:411, ge:413, eq:417, ne:419, cmp:423, isa:425, and:437, or:439, xor:441, not:449, fork:457, getpid:459, time:461, times:463, wait:465, wantarray:467, grep:473, map:475, join:477, sort:479, unpack:481, bless:493, print:497, say:499, printf:501, STDIN:503, STDERR:505, STDOUT:507, exec:511, system:513, SUPER:517, eval:879, do:541, goto:545, push:553, unshift:555, splice:557, pop:561, shift:563, each:567, values:569, keys:571};
const parser = lr.LRParser.deserialize({
  version: 14,
  states: "#HlQ`Q!1hOOP(QOpOOO(YQ!LsO'#JZOOQq'#JZ'#JZOOO#t'#J]'#J]O+nO!!^O'#DVO,hO! pO'#DXOOO#t'#J`'#J`O,oO!!^O'#DYO,wQ!LsO'#J[OOQ'y'#J['#J[O0nQ!LsO'#DcO3xQNYO'#DbOOQq'#Jb'#JbO3}OpO'#DgOOQ'y'#Jc'#JcOOQq'#Jd'#JdOOQq'#Je'#JeOOQq'#Jf'#JfOOQq'#Jg'#JgOOQq'#Di'#DiO4SQ!LsO'#DiO?bQ#${O'#EfOBeQ!LsO'#JaOCRQ!&bO'#DrOOO#t'#Jk'#JkOHbO!!^O'#DtOOQq'#Jh'#JhOHjQNYO'#DwOHuQ!&bO'#DyONUQ!1hO'#EvO!%oQ!&bO'#HRO!%vQ!LsO'#KbO!({O! pO'#EOOOO#t'#Jm'#JmO!)SO!!^O'#EPOOO#t'#Jn'#JnO!)[O!!^O'#ERO!)dOMhO'#ETOOO#t'#Jo'#JoO!)iO!!^O'#EVOOO#t'#Jp'#JpO!)qO!!^O'#EXOOO#t'#Jr'#JrOOO#t'#Js'#JsO!)yO!!^O'#EZO!*RQNYO'#E^O!*^QNYO'#E`O!*iQNYO'#EbO!*wQNYO'#EdOOQt'#Ju'#JuOOQt'#Jv'#JvOOQt'#Jw'#JwOOQt'#Jx'#JxOOQt'#Jt'#JtO!+hQN^O'#EgOOQp'#J{'#J{OOQp'#KO'#KOO!+oQNYO'#EwOOQp'#KQ'#KQOOQp'#KR'#KRO!,YQ$ItO'#E}O!+tQ$ItO'#E}OOQ'x'#KU'#KUOOQp'#KZ'#KZO!,jQNYO'#F]O!,oQNZO'#KaO!,}QNZO'#FeOOQp'#Kc'#KcO!-hQNYO'#ElO!-xQNYO'#FfOOQ'y'#Kd'#KdO!3ZQ!&cO'#FjOOQ'x'#Kg'#KgOOQ'x'#Kh'#KhOOQ'x'#Ki'#KiOOQ'x'#Kj'#KjOOQ'x'#Kk'#KkO!3wQNYO'#FiO!4]QNYO'#FqO!4]QNYO'#FvO!4]QNYO'#FwO!4bQNYO'#GPO!4]QNYO'#F{O!4sQ$ItO'#F}O!5[Q!1iO'#GPO!<fQNZO'#GRO!,}QNZO'#GQOOQp'#Ko'#KoOOQp'#Kp'#KpOOQp'#Kq'#KqOOQp'#Kr'#KrOOQp'#Ks'#KsO!<qQNYO'#GSOOQ3O'#GY'#GYOOQ3O'#GZ'#GZO!<vO,UO'#G[OOQ7|'#Ku'#KuOOQ7|'#Kv'#KvO!<{Q!6fO'#G]OOQ3O'#J}'#J}OOQ'x'#LX'#LXO!=QQ!&bO'#HRO!=QQ!&bO'#HRO!=QQ!&bO'#HVOOQq'#LY'#LYOOQq'#LZ'#LZOOQq'#L['#L[OOQq'#L]'#L]OOQq'#L^'#L^OOQq'#L_'#L_O!=XQ!LsO'#HXO!@mQ#${O'#H`OOQ'x'#La'#LaOOQ'x'#Lb'#LbOOQ'x'#Lc'#LcOOQ'x'#Ld'#LdOOQ'x'#Le'#LeOOQ'x'#L`'#L`O!CeQ!&bO'#HaO!MzQ!&bO'#HaO#%_Q!&bO'#HhO!CeQ!&bO'#HgOOQq'#Hi'#HiOOQp'#Lf'#LfO#%fQNYO'#HkOOQ'y'#Li'#LiOOQ'y'#Lj'#LjOOQ'y'#Lk'#LkO#.^Q#${O'#HmOOQ'y'#Lq'#LqOOQ'y'#Lr'#LrO#.tQ#${O'#HtOOQp'#Lt'#LtO#/RQNYO'#HzO#/ZQNYO'#HzO!<qQNYO'#H}O!=QQ!&bO'#IPO#/`OMxO'#IQOOQ'y'#IS'#ISO#6rQ#${O'#IROOQ'y'#Lv'#LvO#>vQ#${O'#ITOOQ'x'#Lw'#LwO#E]Q!&bO'#IVOOQp'#Ly'#LyOOQp'#Lz'#LzOOQp'#L{'#L{OOQp'#Lx'#LxO#EdQNYO'#IZOOQq'#MO'#MOOOQq'#MP'#MPOOQq'#L}'#L}O#EoQ!LsO'#I_OOQp'#MS'#MSOOQp'#MT'#MTOOQp'#MU'#MUOOQp'#MR'#MRO#IZQNYO'#IbOOQq'#Ja'#JaO#IlQNYO'#D`OOQ3O'#Iz'#IzQ`Q!1hOOO#IwO$fO'#CtO#JPO! pO'#CuPOOO)CD|)CD|O#JWQ!&bO,5:hO$ xQN^O,5>cO$']Q!&bO,5:iOOOO'#Ii'#IiO$'dOMhO'#J^O$'lO#tO,59qO$'qO#tO,59qO$'vO!$fO'#JZO$)^O!bO'#CyOOQ'y,59s,59sO$)cO! pO,59sO$)jO!$fO'#JYOOO%|'#JY'#JYOOO%|'#Ig'#IgO$*zO!$fO,59tO$+RO#tO,59tO$ dQN^O,5>cO$+WQN[O'#IkO$+`QNYO,59}O$+hQN[O,59|OOQ'y,5:R,5:RO!4]QNYO,5>hO!=QQ!&bO,5:YO$+pQN[O'#IqO$+xQ!&cO,5;eOOQp,5<d,5<dO$1bQ!1hO,5?bO$1iQ#${O'#EfO$1|Q!LrO,5@|OCRQ!&bO'#DrO$4lQNYO,5:^O$4qQ!&bO'#DzO!+SQN^O'#EgO$4{QNYO'#ElO$5WO#tO'#DvOOQq,5:`,5:`O$5`O#tO,5:`OOQq,5:c,5:cO#JWQ!&bO,5:cO$5eQ!LrO'#JiO$5oQNYO,5:eO$5tQ!LsO'#JiO$5{QNYO,5:fO$6QQNZO'#KwOOQq'#Kx'#KxOOQq'#Ky'#KyOOQq'#Kz'#KzO$6[QNZO'#G`OOQ3O'#Kw'#KwOOQ3O'#Ip'#IpO$6iQ!1hO,5;bOOQ3P,5;b,5;bO$4qQ!&bO,5:fO$8^Q!LsO,5=mO$:`Q!&bO'#KfO!,}QNZO,5<TO!=QQ!&bO,5=OOOQ'x'#K{'#K{O!=QQ!&bO,5=QO$?lQ!&bO,5=TOOQ'x'#K|'#K|OOQ'x'#K}'#K}OOQ'x'#LO'#LOOOQ'x'#LP'#LPO!=QQ!&bO'#IxO$BoQ!LsO,5=TOOQ'x'#LQ'#LQOOQ'x'#LR'#LRO!=QQ!&bO'#IyO$C]Q!LsO,5=TOOQ'x'#LS'#LSOOQ'x'#LT'#LTOOQ'x'#Gy'#GyOOQ'x'#LU'#LUOOQ'x'#LV'#LVOOQ'x'#LW'#LWO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TOOQq,5=q,5=qO$CyQ!&bO,5>sOOQq,5:j,5:jO$DQO! pO,5:jO$DXO!$fO,5:kO$DcO#tO,5:kO$DhO!$fO,5:mO$DrO#tO,5:mO$DwO! pO,5:oO$EOO!$fO,5:qO$EYO#tO,5:qO$E_O!$fO,5:sO$ElO#tO,5:sO$EqO#tO,5:uO$EvO#tO,5:uOOQq,5:x,5:xO#JWQ!&bO,5:xOOQq,5:z,5:zO#JWQ!&bO,5:zOOQq,5:|,5:|O#JWQ!&bO,5:|O$M{Q#${O,5>SO$E{Q#${O,5>SOOQq,5;O,5;OO#JWQ!&bO,5;OO% TQN^O,5;ROOQq,5;R,5;RO% [QNYO,5<QO% aQ$IuO'#EyO% rQ$IuO,5;cO%!QQ(JRO'#EyO%'cQ(JRO,5;iO%,yQ!&bO'#KTO%-QQNYO,5;nOOQp'#KV'#KVO%-YQNYO,5;pOOQp'#KW'#KWO%-kQNYO,5;rOOQq'#KY'#KYO%-vQNZO,5;tO!,}QNZO,5;vOOQp'#K['#K[O%.ZQNYO,5;yOOQq'#K]'#K]OOQq'#K^'#K^O%.hQ$IuO,5;{O%.{QNZO'#EyO!,}QNZO,5;wOOQ'y'#Jj'#JjO%/WQ!&cO'#ItO%/zQNZO,5@{O%0YOqO'#E{OOQ3P'#KP'#KPOOQ3O,5<P,5<PO%0eQ0>YO'#EnOOQq'#Er'#ErO%0lQNYO'#EpOOQq'#Io'#IoO%0tQNYO,5;WOOQq'#Fh'#FhO%0|QNZO,5<QO!<qQNYO,5<nO%1_Q!1hO'#EvOOQq,5;W,5;WO%1oQNYO,5;WO!<qQNYO,5;WO%1wQNYO,5;WO%4fQ!LsO'#KbO%5YQNZO'#KeOOQq,5<U,5<UOCRQ!&bO'#DrO!<qQNYO,5<]O!<qQNYO,5<bO!<qQNYO,5<cO!4]QNYO,5<cO!4]QNYO,5<gO%5zQ$ItO,5<iO%=jQ!1iO,5<kO!<qQNYO,5<gO%=qQ!&cO,5<hO!<qQNYO,5<iO!4]QNYO,5<iO%={QNYO,5<iO%>QQNYO,5<iOOQp'#Kn'#KnO!<qQNYO'#FyOOQ3O,5<k,5<kO%6cQ!1iO,5<kO%>cQNYO'#IvOOQq-E<t-E<tOOQ3O,5<l,5<lOOQ3O,5<n,5<nO%>hO,UO,5<vOOQ3O,5<w,5<wO%>mQ!LsO,5=mO%@oQ!LsO,5=qO%DQQNYO,5=sOOQq,5=z,5=zO%DVQ!LsO'#KSOOQq'#FR'#FROOQq,5={,5={O!-}Q!&bO,5>iOOQq,5>R,5>RO%EVQNYO'#DzOOQq'#Lh'#LhOOQq'#Lg'#LgO%EmQNYO'#LgOOQq,5>V,5>VO!=QQ!&bO'#LhO%EtQ#${O'#JZO$1iQ#${O'#EfO%MmQ!&bO'#DrOOQ'y'#Lm'#LmOOQ'y'#Ln'#LnOOQ'y'#Lo'#LoOOQ'y'#Lp'#LpOOQq'#Ll'#LlOOQq,5>X,5>XO&%VQ#${O'#LlO&/qQ#${O'#JZO&0RQ!&bO'#DrOOQq'#Ls'#LsO&5bQ#${O'#LsOOQq,5>`,5>`O&5oQ!LsO'#EyO&9WQ!LsO,5>fO&<lQNYO,5>fO&>qQ!LsO,5>kOOQq,5>l,5>lO&@WO`O,5>lOOQq,5>m,5>mOOQq,5>o,5>oO&G|Q#${O,5>qO&JpQ!LsO,5>qO%-QQNYO'#L|O&LPQNYO'#L|OOQq,5>u,5>uOOQq'#MQ'#MQO&LXQNYO'#MQOOQq,5>y,5>yOOQq'#MV'#MVO&LaQNYO'#MVOOQq,5>|,5>|OOQq,59z,59zO#JWQ!&bO,59zOOQ3O-E<x-E<xOOO%},59`,59`O&LoOpO,59`O&LtO! pO,59aOOO%},59a,59aO' bQ!LrO1G0SO#JWQ!&bO1G0SO' iQ!&bO1G0TOOQq'#Hy'#HyO' pQ!LsO1G3}O'%UQNYO1G3}O'%ZQ#$zO1G0TO''iQ!LrO1G0TOOOO-E<g-E<gO''pO!!^O,5?xO''{O#tO1G/]O'(QO#tO1G/]O'(VOMhO'#IhO'([O!bO,59fO'(dOMhO,59mO'(xOMhO,59mO')QOMhO,59mO')]OMhO,59kO')wOMhO,59eOOQ'y1G/_1G/_OOO%|-E<e-E<eOOQ'y1G/`1G/`O')|O!$fO1G/`O')|O!$fO1G/`OOQp,5?V,5?VOOQp-E<i-E<iOOQq'#Dd'#DdOOQq1G/h1G/hOOQq1G4S1G4SO'*TQ!LsO1G/tOOQ'y,5?],5?]OOQ'y-E<o-E<oO$6QQNZO'#IwOOQ3O'#Iw'#IwO'+dQ!1hO1G4|OOQq1G4|1G4|O'+kQ!&cO'#IlO',XQNYO,5@TPOQq1G6h1G6hOOQq1G/x1G/xOOO#t'#Im'#ImO',jO#tO,5:bOOQq,5:b,5:bOOQq1G/z1G/zO',rQ!LrO1G/}OOQq1G0P1G0POOQq1G0Q1G0QOOQ3O,5Ac,5AcOOQ3O,5<z,5<zO!,}QNZO,5<zO$6QQNZO,5<zOOQ3O-E<n-E<nOOQ3P1G0|1G0|O',yQNYO1G0QOOQq,5AQ,5AQOOQ3O1G1o1G1oO'-OQ!LsO1G2jO'._Q!LsO1G2lO'2|Q!LsO1G2oO!=QQ!&bO1G2lO'5^Q!LsO,5?dOOQq-E<v-E<vO'8pQ!LsO,5?eOOQq-E<w-E<wO':PQ!LsO1G2oO'=`Q!LsO1G2oO'=mQ!LsO1G2oO'@|Q!LsO1G2oO'AaQ!LsO1G2oO'ESQ!LsO1G2oO'EZQ!LsO1G2oO'HpQ!LsO1G2oO'HwQ!LsO1G2oO'LTQ!LsO1G2oO'LeQ!LsO1G2oO'LuQ!LsO1G2oO'NUQ!LrO1G4_O!=QQ!&bO1G4_OOQq1G0U1G0UO'N]O#tO1G0VOOQq1G0V1G0VO'NbO!$fO1G0VO'NiO!$fO1G0VO'NsO#tO1G0XO'NxO&jO1G0XO( QO!$fO1G0XO( XO!$fO1G0XO( cO&jO1G0ZO( kO! pO1G0ZO( rO#tO1G0]O( wO&jO1G0]O(!PO!$fO1G0]O(!WO!$fO1G0]OOO%|'#Jq'#JqO(!bO!!^O'#JqO(!jO#tO1G0_O(!rO!$fO1G0_O(!|O!$fO1G0_O(#WO!$fO1G0_O(!jO#tO1G0aO(#eO#tO1G0aO(#jQ!LrO1G0dO(#qQ!LrO1G0fO(#xQ!LrO1G0hO($PQ#${O,5;eO(&nQ!LrO1G0jO0]QNYO'#DcOOQp'#Jz'#JzO(&uQN^O'#JzO('WQNYO'#JyO('cQNYO1G0mO%0|QNZO1G1lO('hQ$IuO,5;eOOQ3O1G0}1G0}O('yQNZO1G0}O((UQ(JRO,5;eOOQ3O1G1T1G1TO!,}QNZO1G1TO%'fQ!&cO1G1TO(-gQ!LrO,5@oOOQp,5@o,5@oO(-qQNYO1G1YO!,}QNZO1G1[OOQq'#KX'#KXO!,}QNZO1G1^OOQ3O1G1`1G1`O!,}QNZO1G1`OOQ3O1G1b1G1bOOQp'#Ef'#EfO%-QQNYO1G1eO!,}QNZO1G1eOOQq'#K`'#K`O%-YQNYO'#K`O(-{QNZO'#K_O!,}QNZO1G1gO(.ZQNYO1G1gOOQ3O1G1c1G1cOOQq,5?`,5?`OOQq-E<r-E<rOOOq'#Ir'#IrO(.`OqO,5;gOOQ3P,5;g,5;gOOQq,5;Y,5;YO(.kQNYO,5;YO(.pQNYO,5:^O(.uQNZO,5;[OOQp'#J|'#J|O(/WQNYO,5;`OOQq-E<m-E<mO!<qQNYO1G0rO%1wQNYO1G0rO%0tQNYO1G1lOOQ3O1G1l1G1lO(/]QNZO1G1lO('yQNZO1G1lO%1wQNYO1G1lOOQ3O1G2Y1G2YO(/kQNYO'#EpO%1oQNYO1G0rOOQq1G0r1G0rO%1wQNYO1G0rO(/pQNZO,5APO(0bQ!1hO1G1wO(7iQ!1hO1G1|O(>pQ!1hO1G1}O!<qQNYO1G1}O!<qQNYO1G2RO%=qQ!&cO1G2SO!<qQNYO1G2TO!4]QNYO1G2TO(EtQNYO1G2TO(EyQNYO1G2TOOQ3O1G2V1G2VO(F[Q!1iO1G2VO(McQ!1hO1G2RO)&gQ!LsO1G2SO!,}QNZO1G2SO)&qQ!1hO1G2TO)-uQNYO1G2TOOQ3P,5<e,5<eOOQ3O1G2b1G2bOOQq1G3_1G3_O)-zQ#${O'#IlO)1WQ!LsO,5@nO)4[Q!LsO'#KaOOQq1G4T1G4TO$4qQ!&bO,5:fP!=QQ!&bO,5BRO)7mQNYO,5BRO)8aQ!LsO,5BSO);_Q!LsO,5@TO)>cQNYO,5:^OCRQ!&bO,5BWOOQq,5BW,5BWOHuQ!&bO,5:hO)>hQ!&bO,5:iOOQq,5B_,5B_O)D_Q#$zO,5B_O)FWQNYO,5:^OCRQ!&bO,5B_OOQq1G4Q1G4QOOQp'#H{'#H{O)F]QNYO1G4QOOQq1G4W1G4WO!CeQ!&bO,5BhO%-QQNYO,5BhO)FeQNYO,5BlO)FjQNYO,5BqO)FoQ!LrO1G/fOOO%}1G.z1G.zOOO%}1G.{1G.{OOQq7+%n7+%nO)FvQ!LsO'#LgO)IuQ!LrO7+%nO)I|Q#$zO7+%oO)L[Q!LrO7+%oOOQq7+)i7+)iO)LcQNYO7+)iOOQq7+%o7+%oO)LhOMhO'#IjOOO#t'#Ij'#IjO)LpO!!^O1G5dOOQ'y7+$w7+$wO)L{O#tO7+$wO)MQOMjO,5?SOOO!b-E<f-E<fO)MYOMhO1G/XO)M_OMhO1G/XO)MsOMhO1G/VO)N_OMhO1G/XO)NgOMhO1G/VO)NlOMhO1G/VO)NqOMjO1G/POOQ'y7+$z7+$zO)NyO!$fO7+$zOOQ3O,5?c,5?cOOQ3O-E<u-E<uOOQq7+*h7+*hO* QQ!LsO,5?WOOQq-E<j-E<jOOO#t-E<k-E<kOOQq1G/|1G/|OOQq7+%i7+%iOOQ3O1G2f1G2fO!,}QNZO1G2fO*!QQ!LsO7+%lO)0uQNZO,5@nO*(rQ!LsO7+(WO!=QQ!&bO7+)yO**RQ!LsO7+)yOOQq7+%q7+%qO*+bO#tO7+%qO*+gO!$fO7+%qO*+nO&jO7+%sOOQq7+%s7+%sO*+qO&jO7+%sO*+vO#tO7+%sO*+{O!$fO7+%sOOQq7+%u7+%uO*,SO&jO7+%uO*,XO&jO7+%uO*,aO&jO7+%wOOQq7+%w7+%wO*,dO&jO7+%wO*,iO#tO7+%wO*,nO!$fO7+%wOOO%|,5@],5@]O*,uO#tO,5@]O*,zO!$fO7+%yO*-UO#tO7+%yO*-ZO&jO7+%yO*-cO!$fO7+%yO(!jO#tO7+%yO(!|O!$fO7+%yO*-jO#tO7+%{O(!jO#tO7+%{OOQq7+&O7+&OOOQq7+&Q7+&QOOQq7+&S7+&SOOQq7+&U7+&UO*-oQNYO,5@fO*-tQN^O'#InO*.RQNYO,5@eOOQq7+&X7+&XO%0tQNYO7+'WOOQ3O7+'W7+'WO(/]QNZO7+'WO('yQNZO7+'WO%1wQNYO7+'WOOQ3O7+&i7+&iOOQ3O7+&o7+&oO!,}QNZO7+&oO*.^Q(JRO7+&tOOQ3O7+&v7+&vOOQ3O7+&x7+&xOOQ3O7+&z7+&zO#JWQ!&bO7+'POOQ3O7+'P7+'PO*.qQNYO,5@zO*.vQNZO'#IsO*/ZQNZO,5@yOOQ3O7+'R7+'RO*/iQNZO7+'ROOOq-E<p-E<pOOQ3P1G1R1G1ROOQq1G0t1G0tOOQq1G0y1G0yOOQq1G0v1G0vO*/yQ08QO'#EnOOQp1G0z1G0zOOQq7+&^7+&^O%1wQNYO7+&^O!<qQNYO7+&^O(/]QNZO7+'WO%1wQNYO7+'WOOQp'#Kl'#KlO!4]QNYO'#FrOOQ3O'#Iu'#IuO*0RQ!1hO7+'cOOQp'#Km'#KmO!<qQNYO'#FtOOQ3O7+'c7+'cO*7YQ!1hO7+'hOOQ3O7+'h7+'hOOQ3O7+'i7+'iO*>aQ!1hO7+'iO*EeQ!1hO7+'mO)&gQ!LsO7+'nO!,}QNZO7+'nO*LiQ!1hO7+'oO!<qQNYO7+'oO!4]QNYO7+'oO+%mQNYO7+'oOOQ3O7+'q7+'qOOQ3O7+'m7+'mO#JWQ!&bO7+'nO+%rQNYO7+'nOOQ3O7+'o7+'oO+%wQ#${O'#ItO+(oQ!LsO,5@{O+,QQNYO1G0QO+,VQ!LsO1G7mOOQq1G7m1G7mO#JWQ!&bO1G7mOOQq1G7r1G7rO+/hQNYO1G7rO+/mQ!LrO1G0SO+/zQ!LrO1G0TO+0XQNYO1G7yOOQq1G7y1G7yO+0^Q!LsO7+)lOOQq1G8S1G8SO$:`Q!&bO1G8SOOQq1G8W1G8WOOQq1G8]1G8]OOQq7+%Q7+%QOOQq<<IY<<IYOOQq<<IZ<<IZO+3rQ!LsO<<MTOOO#t,5?U,5?UOOO#t-E<h-E<hOOQ'y<<Hc<<HcOOO!b1G4n1G4nOOO%|7+$s7+$sO+7WOMhO7+$sO+7]OMhO7+$qO+7bOMhO7+$qO+7gOMhO7+$sO+7{OMhO7+$qOOO%|7+$q7+$qOOO%|'#C}'#C}OOO%|7+$k7+$kOOQ'y<<Hf<<HfOOQ3O7+(Q7+(QO+:|Q!LsO1G/xO+;aQ!LsO<<MeOOQq<<I]<<I]OOQq<<I_<<I_O+<pO&jO<<I_O+<uO&jO<<I_OOQq<<Ia<<IaO+<}O&jO<<IaOOQq<<Ic<<IcO+=SO&jO<<IcO+=XO&jO<<IcOOO%|1G5w1G5wO+=aO#tO<<IeO+=fO&jO<<IeO+=nO!$fO<<IeOOQq<<Ie<<IeO+=iO&jO<<IeO+=uO!$fO<<IeO+>PO#tO<<IgO+>UO#tO<<IgOOQp1G6Q1G6QOOQp,5?Y,5?YOOQp-E<l-E<lO('yQNZO<<JrO%1wQNYO<<JrO(/]QNZO<<JrOOQ3O<<Jr<<JrO%1wQNYO<<JrOOQ3O<<JZ<<JZOOQ3O<<J`<<J`O!,}QNZO<<J`O%'fQ!&cO<<J`O+>ZQ!&cO<<J`O+>kQ!LsO<<JkOOQq1G6f1G6fOOQq,5?_,5?_OOQq-E<q-E<qO!,}QNZO<<JmO!<qQNYO<<IxOOQq<<Ix<<IxO!<qQNYO,5<^OOQ3O-E<s-E<sOOQ3O<<J}<<J}OOQ3O,5<`,5<`OOQ3O<<KS<<KSOOQ3O<<KT<<KTOOQ3O<<KX<<KXO#JWQ!&bO<<KYO+>uQNYO<<KYOOQ3O<<KZ<<KZO+>zQ!1hO<<KZO!<qQNYO<<KZO!4]QNYO<<KZO+>kQ!LsO<<KYO!<qQNYO<<KYOOQq7+%l7+%lO+FOQ!LrO7+-XOOQq7+-^7+-^OOQq7+-e7+-eOOQq<<MW<<MWO+FVQNYO7+-nO+F[Q!LsO1G/xO+IZQ!LsO1G/xOOQqANBoANBoOOO%|<<H_<<H_OOO%|<<H]<<H]O+LYOMhO<<H]O+L_OMhO<<H_O+LdOMhO<<H]OOQqAN>yAN>yO+LiO&jOAN>yOOQqAN>{AN>{OOQqAN>}AN>}O+LnO&jOAN>}O+LsO&jOAN?POOQqAN?PAN?PO+LvO&jOAN?PO+L{O#tOAN?PO+MQO!$fOAN?PO+MXO&jOAN?RO+MaO#tOAN?ROOQ3OAN@^AN@^O%1wQNYOAN@^O('yQNZOAN@^OOQ3OAN?zAN?zO!,}QNZOAN?zO%'fQ!&cOAN?zOOQ3OAN@VAN@VOOQ3OAN@XAN@XOOQqAN?dAN?dOOQ3O1G1x1G1xO+>kQ!LsOAN@tO!<qQNYOAN@tOOQ3OAN@uAN@uO+MfQ!1hOAN@uO!<qQNYOAN@uO#JWQ!&bOAN@tOOQ3OAN@tAN@tOOQq<=!s<=!sOOQq<=#Y<=#YOOO%|AN=wAN=wOOO%|AN=yAN=yO,&jOMhOAN=wOOQqG24eG24eOOQqG24iG24iOOQqG24kG24kO,&oO&jOG24kO,&tO&jOG24kOOQqG24mG24mO,&|O&jOG24mO,'RO&jOG24mO('yQNZOG25xOOQ3OG25xG25xOOQ3OG25fG25fO!,}QNZOG25fO#JWQ!&bOG26`OOQ3OG26`G26`OOQ3OG26aG26aO,'ZQ!1hOG26aO,._Q!LrOG26`OOO%|G23cG23cOOQqLD*VLD*VO,.fO&jOLD*VOOQqLD*XLD*XO,.kO&jOLD*XOOQ3OLD+dLD+dOOQ3OLD+QLD+QO,.pQ!LrOLD+zOOQ3OLD+{LD+{O!<qQNYOLD+zOOQq!$'Mq!$'MqOOQq!$'Ms!$'MsO!<qQNYO!$( fOOQ3O!$( f!$( fOOQ3O!)9EQ!)9EQO,.wQNYO'#E^O#%fQNYO'#HkO#JWQ!&bO'#IPO,/SQ#${O'#IRO,/vQ#${O'#ITO,0jQ!&bO'#IVO,0qQNYO'#D`O#JWQ!&bO'#HRO#JWQ!&bO,5:YO,0|Q#${O'#EfO,3kQ!LsO'#JiO#JWQ!&bO,5=OO#JWQ!&bO,5=QO,4bQ!&bO,5=TO#JWQ!&bO'#IxO,6xQ!LsO,5=TO#JWQ!&bO'#IyO,7fQ!LsO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO,8SQ!LsO'#KbO,=qQ!LsO,5=mO,>bQ!LsO'#KSO,>uQ#$zO'#JZO,FoQ#${O'#JZO,IWQ#${O'#JZO,K`Q!LsO,5>kO,L]Q#${O,5>qO,NjQ!LsO,5>qO- aQ#$zO1G0TO-#rQ!LsO1G/tO-$cQ!LsO1G2jO-%SQ!LsO1G2lO-(iQ!LsO1G2oO#JWQ!&bO1G2lO-(pQ!LsO,5?dO-)dQ!LsO,5?eO-*ZQ!LsO1G2oO--QQ!LsO1G2oO--_Q!LsO1G2oO-0UQ!LsO1G2oO-0iQ!LsO1G2oO-3rQ!LsO1G2oO-3yQ!LsO1G2oO-6vQ!LsO1G2oO-6}Q!LsO1G2oO-9qQ!LsO1G2oO-:RQ!LsO1G2oO-:cQ!LsO1G2oO#JWQ!&bO1G4_O-;SQNYO,5:^O#JWQ!&bO,5BRO-;XQ!LrO,5BSO-;fQNYO,5:^O-;kQNYO,5:^O-;pQ!LsO7+(WO#JWQ!&bO7+)yO-<aQ!LsO7+)yO-=WQ!LrO1G/xO-=bQ!LsO1G/xO-@aQ!LsO<<MeO-AWQ!LsO'#JaO-FhQ!&bO'#HRO#JWQ!&bO'#HRO#JWQ!&bO'#HVO-KxQ#${O'#H`O.(QQ#${O'#HmO.(hQ#${O'#HtO.(uQ!&bO,5>sOCRQ!&bO'#DrO!=QQ!&bO'#LhO%MmQ!&bO'#DrO&0RQ!&bO'#DrO.(|Q!LrO1G4_O.)TQ!&bO,5BhO.)[QNYO,5:^O.)aQNYO,5:^O.)TQ!&bO'#HaO..oQ!&bO'#HaO.)TQ!&bO'#HgO%-QQNYO'#L|OCRQ!&bO'#DrOCRQ!&bO'#DrO..vQNYO'#IZ",
  stateData: "./q~OgOS'{OS'rPQ'sPQ~OQ]OR#dOS#kOT#}OU$OOd#SOjQOkROlROpfOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO#l!ZO#p#RO#r!]O#s!^O#w!aO$Q!bO$Z!fO$_!iO$`!kO$a!lO$b!mO$c!nO$d!oO$w!zO$x!{O$y!|O$z!}O${#OO%Q#TO%R#UO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO)h#QO*i$PO~O'r$iO's$jO~Ov$mOw$nO!O$lOo'}X!Q'}X!['}X!c'}X!g'}X!o'}X!x'}X#T'}X#V'}X#X'}X#p'}X#w'}X$`'}X$a'}X$b'}X$c'}X$d'}X%X'}X%Z'}X%['}X%^'}X%_'}X%`'}X%a'}X%b'}X%c'}X%d'}X%e'}X%f'}X%g'}X%h'}X%i'}X%j'}X%k'}X%l'}X%n'}X%o'}X%p'}X%q'}X%r'}X%s'}X%t'}X%z'}X&|'}X'p'}X!d'}Xr'}Xt'}X#e'}X~O^$qO'{$oO~OQ$xO[$xO]$xOj$sOkROlRO!T5OO#R4xO'r$iO's$jO~O(R$uO~P+vO^$zO'{$oO~Ov$|Ov(OXw(OX!O(OX!Q(OX![(OX!c(OX!g(OX!o(OX!x(OX#T(OX#V(OX#X(OX#p(OX#w(OX$`(OX$a(OX$b(OX$c(OX$d(OX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX%z(OX&|(OX'p(OX!d(OXr(OXt(OX#e(OX~Oo$}Oo!VX!c(UX!g(UX!d(UX~Ov(UXw(UX!O(UX!Q(UX![(UX!o(UX!x(UX#T(UX#V(UX#X(UX#p(UX#w(UX$`(UX$a(UX$b(UX$c(UX$d(UX%X(UX%Z(UX%[(UX%^(UX%_(UX%`(UX%a(UX%b(UX%c(UX%d(UX%e(UX%f(UX%g(UX%h(UX%i(UX%j(UX%k(UX%l(UX%n(UX%o(UX%p(UX%q(UX%r(UX%s(UX%t(UX%z(UX&|(UX'p(UXr(UXt(UX#e(UX~P0]Oo%PO~OY%QO~Ov%ROw!]X!O!]X!Q!]X![!]X!c!]X!g!]X!o!]X!x!]X#T!]X#V!]X#X!]X#p!]X#w!]X$`!]X$a!]X$b!]X$c!]X$d!]X%X!]X%Z!]X%[!]X%^!]X%_!]X%`!]X%a!]X%b!]X%c!]X%d!]X%e!]X%f!]X%g!]X%h!]X%i!]X%j!]X%k!]X%l!]X%n!]X%o!]X%p!]X%q!]X%r!]X%s!]X%t!]X%z!]X&|!]X'p!]X!d!]Xr!]Xt!]X#e!]X~Oo%TO!c%SOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv#mXx&[Xz&[X}&[X!O&[X!P&[X!Q&[X!R&[X!T&[X!X&[X!Y&[X![&[X!^&[X!_&[X!`&[X!a&[X!e&[X!g#YX!i&[X!l&[X!o&[X!t&[X!v&[X!x#YX!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X#p#YX#w#YX$`#YX$a#YX$b#YX$c#YX$d#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|#YX'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'p#YX'w&[X(R&[X(`&[X*i&[Xt#YX~Ow%WO#e%VO~P7eOv(TXw(TX!O(TX!Q(TX![(TX!o(TX!x(TX#T(TX#V(TX#X(TX#p(TX%X(TX%Z(TX%[(TX%^(TX%_(TX%`(TX%a(TX%b(TX%c(TX%d(TX%e(TX%f(TX%g(TX%h(TX%i(TX%j(TX%k(TX%l(TX%n(TX%o(TX%p(TX%q(TX%r(TX%s(TX%t(TX%z(TX&|(TX'p(TX!d(TXr(TXt(TX#e(TX~O!c%SO!g(TX#w(TX$`(TX$a(TX$b(TX$c(TX$d(TX~P?lOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO!d(]P~O^%`O'{$oO~Oj%cOp%cOw%dO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POr(]P~O%T%jO%U%kO%V%lOt(]P~P`OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~Ow%rO~PNfOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!c)UX!g)UX#p)UX'p)UX~O(`&kO~P+vO^&mO'{$oO~O^&oO'{$oO~O!x&qO~O^&rO'{$oO~O^&tO'{$oO~O^&vO'{$oO~Oj&xOw&yO!T$fO~Oj&zOw&{O!T$fO~Oj&|Op'OOw&}O!T$fO~Oj'QOw'RO!T$fO~OQ]OjROkROlRO!X'TO!e'SO~O#a!YO~P!+SOp'VO~Op'XO#n'cO#t'YO#w!aO#{'_O#}'aO~O#y']O$S'dO$U'fO$V'gO~P!+tOp'iO~O!c'kO!g'kO#p)TX'p)TX~O#p'nO'p'oO~O$w!zO$x!{O$y!|O$z!}O${#OO~Op'vOw'yO!e'qO#e'sO~P!-VO#a!YO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~O#w)XP$`)XP$a)XP$b)XP$c)XP$d)XP#p)XP'p)XP~P!-}O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO~O!e(RO~Ow'yO$a!lO$b!mO$c!nO$d!oO~Oj(^O!e([O#[!SO#]!TO#^!UO#_!VO$r(`O~O#p'nO$n(aO'p'oOQ$sXR$sXS$sXT$sXU$sXd$sXj$sXk$sXl$sXp$sXw$sXx$sXz$sX}$sX!O$sX!P$sX!Q$sX!R$sX!T$sX!X$sX!Y$sX![$sX!^$sX!_$sX!`$sX!a$sX!e$sX!i$sX!l$sX!o$sX!t$sX!v$sX!z$sX!|$sX#O$sX#P$sX#R$sX#T$sX#V$sX#X$sX#[$sX#]$sX#^$sX#_$sX#a$sX#l$sX#p$sX#r$sX#s$sX#w$sX$Q$sX$Z$sX$_$sX$`$sX$a$sX$b$sX$c$sX$d$sX$w$sX$x$sX$y$sX$z$sX${$sX%Q$sX%R$sX%v$sX%w$sX%x$sX%z$sX%|$sX%}$sX&O$sX&P$sX&Q$sX&R$sX&U$sX&V$sX&W$sX&X$sX&Y$sX&`$sX&b$sX&c$sX&d$sX&i$sX&j$sX&l$sX&x$sX&z$sX'O$sX'P$sX'Q$sX'S$sX'T$sX'V$sX'W$sX'X$sX'o$sX'w$sX(R$sX(`$sX)h$sX*i$sXt$sX%T$sX%U$sX%V$sX~Op(eO#p$uX'p$uX~Ow'yO~Oe(iO~O'y(jO~Ow%]O~PNfO!e(mOv%{Xw%{X!O%{X!Q%{X![%{X!c%{X!g%{X!o%{X!x%{X#T%{X#V%{X#X%{X#p%{X#w%{X$`%{X$a%{X$b%{X$c%{X$d%{X%X%{X%Z%{X%[%{X%^%{X%_%{X%`%{X%a%{X%b%{X%c%{X%d%{X%e%{X%f%{X%g%{X%h%{X%i%{X%j%{X%k%{X%l%{X%n%{X%o%{X%p%{X%q%{X%r%{X%s%{X%t%{X%z%{X&|%{X'p%{X!d%{Xr%{Xt%{X#e%{X~Ov&SX!c&SX!g&SX!x&SX#p&SX#w&SX$`&SX$a&SX$b&SX$c&SX$d&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SX'p&SX!d&SXr&SXt&SX#e&SX~P!-}OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(RO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(RO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~OwnO~P!HqOQ&[XR&[XS&[XT&[XU&[Xj&[Xk&[Xl&[Xp&[Xw&[Xx&[Xz&[X}&[X!O&[X!P&[X!Q&[X!R&[X!T&[X!X&[X!Y&[X![&[X!^&[X!_&[X!`&[X!a&[X!e&[X!i&[X!l&[X!o&[X!t&[X!v&[X!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'w&[X(R&[X(`&[X*i&[X~Ov$|O~P!NROj(uOw%]O!OmO!e(wO!o(tO#a!YO%w(yO~OQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POv(]Pw(]P!O(]P!Q(]P!c(]P!g(]P!o(]P!x(]P#T(]P#V(]P#X(]P#p(]P#w(]P$`(]P$a(]P$b(]P$c(]P$d(]P%X(]P%Z(]P%[(]P%^(]P%_(]P%`(]P%a(]P%b(]P%c(]P%d(]P%e(]P%f(]P%g(]P%h(]P%i(]P%j(]P%k(]P%l(]P%n(]P%o(]P%p(]P%q(]P%r(]P%s(]P%t(]P%z(]P&|(]P'p(]P!d(]Pr(]Pt(]P#e(]P~Oj(zOp({O!e(|O&e(}O&f)OO&g)PO~P#%}Oj)UOp%XO!e)VO~P#%}Oj)[Op)ZO~Oo)]O~OV)`OW)`OX)_Oj)`Op)`O&e(}O&f)OO&g)PO~OQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POv&uX!x&uX#p&uX%X&uX%Z&uX%[&uX%^&uX%_&uX%`&uX%a&uX%b&uX%c&uX%d&uX%e&uX%f&uX%g&uX%h&uX%i&uX%j&uX%k&uX%l&uX%n&uX%o&uX%p&uX%q&uX%r&uX%s&uX%t&uX&|&uX'p&uX!d&uXr&uXt&uX#e&uX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%v#YO%w#YO%z#[O!c&uX!g&uX#w&uX$`&uX$a&uX$b&uX$c&uX$d&uX~P#/zOQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POv&wX!x&wX#p&wX%X&wX%Z&wX%[&wX%^&wX%_&wX%`&wX%a&wX%b&wX%c&wX%d&wX%e&wX%f&wX%g&wX%h&wX%i&wX%j&wX%k&wX%l&wX%n&wX%o&wX%p&wX%q&wX%r&wX%s&wX%t&wX&|&wX'p&wX!d&wXr&wXt&wX#e&wX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%v#YO%w#YO%z#[O!c&wX!g&wX#w&wX$`&wX$a&wX$b&wX$c&wX$d&wX~P#8OOQ]OR#dOS#kOT#}OU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~Op)cO~P#@SOk)eO!e)fO#R!OO~Ok)hO!e)iO#R!OOv'RXw'RX!O'RX!Q'RX!['RX!c'RX!g'RX!o'RX!x'RX#T'RX#V'RX#X'RX#p'RX#w'RX$`'RX$a'RX$b'RX$c'RX$d'RX%X'RX%Z'RX%['RX%^'RX%_'RX%`'RX%a'RX%b'RX%c'RX%d'RX%e'RX%f'RX%g'RX%h'RX%i'RX%j'RX%k'RX%l'RX%n'RX%o'RX%p'RX%q'RX%r'RX%s'RX%t'RX%z'RX&|'RX'p'RX!d'RXr'RXt'RX#e'RX~Ok)kOl)kO!e)lO#R!OO#T!PO~Oj)nOw)oO!T$fO~OZ)qOa)rO~OZ)tO~P+vOQ]OR6hOS6tOT4zOU$OOjQOkROlROp5ROw%]OxXOzSO}VO!OmO!P$eO!Q5PO!R$eO!T$fO!X$eO!Y6dO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6eO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5PO%w5PO%x#XO%z6gO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~OQ)yOj)yOp)xO!T$fO!e(RO&l#yO~Ow)wO!O)vO~P$ dOQ]OR6hOS6tOT4zOU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q5PO!R$eO!T$fO!X$eO!Y6dO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6eO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5PO%w5PO%x#XO%z6gO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~Op){O~P$!SOg*OO'{$oO~Oa*PO~O^*QO~Ov*UOw*TO!O*WO't*VO'u*ROQ'}X['}X]'}Xj'}Xk'}Xl'}X!T'}X#R'}X'r'}X's'}X'vnX(R'}X(`'}XZ'}X`'}X!x'}X_'}X~O'v*XO~O(R*YO~P+vOv*UOw*TO!O*WO't*VOQ'|X['|X]'|Xj'|Xk'|Xl'|X!T'|X#R'|X'r'|X's'|X(R'|X(`'|XZ'|X`'|X!x'|X_'|X~O`*[O~P+vO^*^O~OP*_Op*_O~Oo$}Oo!Va~OP*aOp*aO~OP*eOp*eO~Oo%TOQ#maR#maS#maT#maU#maj#mak#mal#map#mav#maw#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'w#ma(R#ma(`#ma*i#ma#p#ma'p#ma~Ot*jO~P`Ow&[Xw&rX!d#YXr#YX#e#YX~P7eOv$mOw$nO!O$lO!Q&^O![&_O!c'kO!g'kO!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!d(]X~O!d*nO~Ow%]Ot(]P~PNfOw'yO!e'qO#e'sO~O`*qOb*oO~O^%`O~Or(]Xt(]X~P$1|Or*tO~Ot(]X~P!%vOt*uO~O#p'nO'p'oO~P!3wOp*yO#p'nO'p'oO~P!3wOt*{O%T%jO%U%kO%V%lO~P`Ov$mOw$nO!O$lO%z&iO!c%ua!g%ua#p%ua#w%ua$`%ua$a%ua$b%ua$c%ua$d%ua%r%ua%s%ua%t%ua'p%ua!d%uar%uat%ua#e%ua~O!Q%ua![%ua!o%ua!x%ua#T%ua#V%ua#X%ua%X%ua%Z%ua%[%ua%^%ua%_%ua%`%ua%a%ua%b%ua%c%ua%d%ua%e%ua%f%ua%g%ua%h%ua%i%ua%j%ua%k%ua%l%ua%n%ua%o%ua%p%ua%q%ua&|%ua~P$6yOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6lO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~Ow%]O%X+SO~PNfOv%]aw%]a!O%]a!Q%]a![%]a!c%]a!g%]a!o%]a!x%]a#T%]a#V%]a#X%]a#p%]a#w%]a$`%]a$a%]a$b%]a$c%]a$d%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]a'p%]a!d%]ar%]at%]a#e%]a~O%b&OO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P$?vO%g&SO%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P$?vO#e+fO~P#JWO(`+gO~P+vO`+iOa+hO~P+vO^+kO~O`+mOa+lO~P+vO^+oO~O!x+pO~P+vO`+sOa+rO~P+vO^+uO~O_+vO`+wOa+xO~P+vO^+{O~Oa+|O~O^+}O~OQ&[aR&[aS&[aT&[aU&[aj&[ak&[al&[ap&[av&^aw&[ax&[az&[a}&[a!O&[a!P&[a!Q&[a!R&[a!T&[a!X&[a!Y&[a![&[a!^&[a!_&[a!`&[a!a&[a!c&^a!e&[a!g&^a!i&[a!l&[a!o&[a!t&[a!v&[a!x&^a!z&[a!|&[a#O&[a#P&[a#R&[a#T&[a#V&[a#X&[a#[&[a#]&[a#^&[a#_&[a#a&[a#p&^a#w&^a$`&^a$a&^a$b&^a$c&^a$d&^a%X&^a%Z&^a%[&^a%^&^a%_&^a%`&^a%a&^a%b&^a%c&^a%d&^a%e&^a%f&^a%g&^a%h&^a%i&^a%j&^a%k&^a%l&^a%n&^a%o&^a%p&^a%q&^a%r&^a%s&^a%t&^a%v&[a%w&[a%x&[a%z&[a%|&[a%}&[a&O&[a&P&[a&Q&[a&R&[a&U&[a&V&[a&W&[a&X&[a&Y&[a&`&[a&b&[a&c&[a&d&[a&i&[a&j&[a&l&[a&x&[a&z&[a&|&^a'O&[a'P&[a'Q&[a'S&[a'T&[a'V&[a'W&[a'X&[a'p&^a'w&[a(R&[a(`&[a*i&[a!d&^ar&^at&^a#e&^a~Oo%TOw&^a!O&^a!Q&^a![&^a!o&^a#T&^a#V&^a#X&^a%z&^a~P$E{OQ]OjROkROlRO!X,UO!e,VO~O!d(mP~P$NoOp'vO~Oo%TOw#mX#n#mX#p#mX'p#mX~Ow'yO#n,]O#p'nO'p'oO~OQ#mXR#mXS#mXT#mXU#mXj#mXk#mXl#mXp#mXx#mXz#mX}#mX!O#mX!P#mX!Q#mX!R#mX!T#mX!X#mX!Y#mX![#mX!^#mX!_#mX!`#mX!a#mX!e#mX!i#mX!l#mX!o#mX!t#mX!v#mX!z#mX!|#mX#O#mX#P#mX#R#mX#T#mX#V#mX#X#mX#[#mX#]#mX#^#mX#_#mX#a#mX%v#mX%w#mX%x#mX%z#mX%|#mX%}#mX&O#mX&P#mX&Q#mX&R#mX&U#mX&V#mX&W#mX&X#mX&Y#mX&`#mX&b#mX&c#mX&d#mX&i#mX&j#mX&l#mX&x#mX&z#mX'O#mX'P#mX'Q#mX'S#mX'T#mX'V#mX'W#mX'X#mX'w#mX(R#mX(`#mX*i#mX!c#mX!g#mX~P% aO#n,aO#p'nO'p'oO~P$:`OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~O!e6yO~P%'pO!c'kO!g'kO~OxYOzSO}VO![^O(RUO~Ok,fO!e%ZO!iiO~Ok,fO!e%ZO!iiO#p'nO'p'oO~P%-YOp,kOw%]O!o(tO~P%-YO!e,oO!iiO$W,rO#p)RP'p)RP~P%-YOo%TO#p#mX'p#mX~O!c'hX!g'hX#p'hX'p'hX#w'hX$`'hX$a'hX$b'hX$c'hX$d'hX~P!-}O!c'kO!g'kO#p)Ta'p)Ta~O'q,xO'r$iO's$jO~O#c,zO~PCROp,|O#i,}O~O!e(RO#e'sO~Ow'yO!e'qO#e'sO#p'nO'p'oO~Ot%qO%T%jO%U%kO%V%lO~P`Ow'yO#e-YO~O!e(RO#e-YO~Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO~O!c)UX!g)UX#w)UX$`)UX$a)UX$b)UX$c)UX$d)UX#p)UX'p)UX~P%2PO!c'kO!g'kO#w)XX$`)XX$a)XX$b)XX$c)XX$d)XX#p)XX'p)XX~Oj-fO!e-dO#[!SO#]!TO#^!UO#_!VO$r-hO~O#p'nO'p'oOQ$saR$saS$saT$saU$sad$saj$sak$sal$sap$saw$sax$saz$sa}$sa!O$sa!P$sa!Q$sa!R$sa!T$sa!X$sa!Y$sa![$sa!^$sa!_$sa!`$sa!a$sa!e$sa!i$sa!l$sa!o$sa!t$sa!v$sa!z$sa!|$sa#O$sa#P$sa#R$sa#T$sa#V$sa#X$sa#[$sa#]$sa#^$sa#_$sa#a$sa#l$sa#p$sa#r$sa#s$sa#w$sa$Q$sa$Z$sa$_$sa$`$sa$a$sa$b$sa$c$sa$d$sa$w$sa$x$sa$y$sa$z$sa${$sa%Q$sa%R$sa%v$sa%w$sa%x$sa%z$sa%|$sa%}$sa&O$sa&P$sa&Q$sa&R$sa&U$sa&V$sa&W$sa&X$sa&Y$sa&`$sa&b$sa&c$sa&d$sa&i$sa&j$sa&l$sa&x$sa&z$sa'O$sa'P$sa'Q$sa'S$sa'T$sa'V$sa'W$sa'X$sa'o$sa'w$sa(R$sa(`$sa)h$sa*i$sat$sa%T$sa%U$sa%V$sa~O$n(aO~P%6cO#p'nO'p'oO~PCROj-fO~Ol-fO#[!SO#]!TO#^!UO#_!VO~Ow%WO~Of-qO~O!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO&|&jO~P$6yOv$mOw$nO!O$lO!Q%ya![%ya!c%ya!g%ya!o%ya!x%ya#T%ya#V%ya#X%ya#p%ya#w%ya$`%ya$a%ya$b%ya$c%ya$d%ya%X%ya%Z%ya%[%ya%^%ya%_%ya%`%ya%a%ya%b%ya%c%ya%d%ya%e%ya%f%ya%g%ya%h%ya%i%ya%j%ya%k%ya%l%ya%n%ya%o%ya%p%ya%q%ya%r%ya%s%ya%t%ya%z%ya&|%ya'p%ya!d%yar%yat%ya#e%ya~O!d-rO~O!c'kO!g'kO#p(vX#w(vX$`(vX$a(vX$b(vX$c(vX$d(vX'p(vX!d(vXr(vXt(vX#e(vX~P%2POw-wO~Oj(uOw%]O!OmO!o(tO#a!YO~O%w6mO~P%E[OQ*dXR*dXS*dXT*dXU*dXj*dXk*dXl*dXp*dXx*dXz*dX}*dX!P*dX!Q*dX!R*dX!T*dX!X*dX!Y*dX![*dX!^*dX!_*dX!`*dX!a*dX!c*dX!e*dX!g*dX!i*dX!l*dX!o*dX!t*dX!v*dX!x*dX!z*dX!|*dX#O*dX#P*dX#R*dX#T*dX#V*dX#X*dX#[*dX#]*dX#^*dX#_*dX#a*dX#p*dX#w*dX$`*dX$a*dX$b*dX$c*dX$d*dX%X*dX%Z*dX%[*dX%^*dX%_*dX%`*dX%a*dX%b*dX%c*dX%d*dX%e*dX%f*dX%g*dX%h*dX%i*dX%j*dX%k*dX%l*dX%n*dX%o*dX%p*dX%q*dX%r*dX%s*dX%t*dX%v*dX%w*dX%x*dX%z*dX%|*dX%}*dX&O*dX&P*dX&Q*dX&R*dX&U*dX&V*dX&W*dX&X*dX&Y*dX&`*dX&b*dX&c*dX&d*dX&i*dX&j*dX&l*dX&x*dX&z*dX&|*dX'O*dX'P*dX'Q*dX'S*dX'T*dX'V*dX'W*dX'X*dX'p*dX'w*dX(R*dX(`*dX*i*dX!d*dXr*dXt*dX#e*dX~P(YOQ]OR#dOS#kOT#}OU$OOj5lOkROlROp({OwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&e(}O&f)OO&g)PO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO!d(]P~Ov(]P!c(]P!g(]P!x(]P#p(]P#w(]P$`(]P$a(]P$b(]P$c(]P$d(]P%X(]P%Z(]P%[(]P%^(]P%_(]P%`(]P%a(]P%b(]P%c(]P%d(]P%e(]P%f(]P%g(]P%h(]P%i(]P%j(]P%k(]P%l(]P%n(]P%o(]P%p(]P%q(]P%r(]P%s(]P%t(]P&|(]P'p(]Pr(]Pt(]P#e(]P~PCROQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO!c(]P!g(]P!x(]P#p(]P#w(]P$`(]P$a(]P$b(]P$c(]P$d(]P%X(]P%Z(]P%[(]P%^(]P%_(]P%`(]P%a(]P%b(]P%c(]P%d(]P%e(]P%f(]P%g(]P%h(]P%i(]P%j(]P%k(]P%l(]P%n(]P%o(]P%p(]P%q(]P%r(]P%s(]P%t(]P&|(]P'p(]P!d(]Pr(]Pt(]P#e(]P~Ov$mOw.QO!O.POo'}X~P&'zOQ]OR#dOS#kOT#}OU$OOj.SOkROlROp%XOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO!d(]P~Ow%]O!OmOv(]P~P&'zOo%TOv#mXw#mX!O#mX!Q#mX![#mX!c#mX!e#mX!g#mX!o#mX!x#mX#T#mX#V#mX#X#mX#p#mX#w#mX$`#mX$a#mX$b#mX$c#mX$d#mX%X#mX%Z#mX%[#mX%^#mX%_#mX%`#mX%a#mX%b#mX%c#mX%d#mX%e#mX%f#mX%g#mX%h#mX%i#mX%j#mX%k#mX%l#mX%n#mX%o#mX%p#mX%q#mX%r#mX%s#mX%t#mX%z#mX&|#mX'p#mX!d#mXr#mXt#mX#e#mX~O!e(ROv&naw&na!O&na!Q&na![&na!c&na!g&na!o&na!x&na#T&na#V&na#X&na#p&na#w&na$`&na$a&na$b&na$c&na$d&na%X&na%Z&na%[&na%^&na%_&na%`&na%a&na%b&na%c&na%d&na%e&na%f&na%g&na%h&na%i&na%j&na%k&na%l&na%n&na%o&na%p&na%q&na%r&na%s&na%t&na%z&na&|&na'p&na!d&nar&nat&na#e&na~Op.WO~Ov$mOw$nO!O$lO%[%wO%c%zO%d%{O%e%|O%f%}O%h&QO%i&RO%k&UO%z&iO#V&sa#p&sa%X&sa%Z&sa%l&sa%n&sa%o&sa%p&sa%q&sa%r&sa%s&sa%t&sa&|&sa'p&sa!d&sar&sat&sa#e&sa~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO%g&SO%j&`O!c&sa!g&sa#w&sa$`&sa$a&sa$b&sa$c&sa$d&sa~P&<qOX.YO~Oo%TOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv&yaw&yax&[Xz&[X}&[X!O&ya!P&[X!Q&ya!R&[X!T&[X!X&[X!Y&[X![&ya!^&[X!_&[X!`&[X!a&[X!e&[X!i&[X!l&[X!o&ya!t&[X!v&[X!x&ya!z&[X!|&[X#O&[X#P&[X#R&[X#T&ya#V&ya#X&ya#[&[X#]&[X#^&[X#_&[X#a&[X#p&ya%X&ya%Z&ya%[&ya%^&ya%_&ya%`&ya%a&ya%b&ya%c&ya%d&ya%e&ya%f&ya%g&ya%h&ya%i&ya%j&ya%k&ya%l&ya%n&ya%o&ya%p&ya%q&ya%r&ya%s&ya%t&ya%v&[X%w&[X%x&[X%z&ya%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|&ya'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'p&ya'w&[X(R&[X(`&[X*i&[X!d&yar&yat&ya#e&ya~O!c&ya!g&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya~P&@]Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%z&iO&|&jO~O!c&ya!g&ya#p&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya%X&ya%Z&ya%r&ya%s&ya%t&ya'p&ya!d&yar&yat&ya#e&ya~P&HjOk.[O#R!OO~Ok.]O#R!OO~Ok.^Ol.^O#R!OO#T!PO~OZ.`O~OZ.aO~P+vOv$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#V&WO#X5]O%X5TO%Z5UO%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%n5cO%o5dO%p5eO%q5fO%r&XO%s&YO%t&ZO%z&iO&|6kO~Or.bO~P&L{Op.eO~P$!SO!e(ROv&kiw&ki!O&ki!Q&ki![&ki!c&ki!g&ki!o&ki!x&ki#T&ki#V&ki#X&ki#p&ki#w&ki$`&ki$a&ki$b&ki$c&ki$d&ki%X&ki%Z&ki%[&ki%^&ki%_&ki%`&ki%a&ki%b&ki%c&ki%d&ki%e&ki%f&ki%g&ki%h&ki%i&ki%j&ki%k&ki%l&ki%n&ki%o&ki%p&ki%q&ki%r&ki%s&ki%t&ki%z&ki&|&ki'p&ki!d&kir&kit&ki#e&ki~Oo.hO~Oo%TOt.iO!c5QOj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt.iO~P&L{Og.kO'{$oO^(Qa~O`.mO~Oa.nO~Oo.oO~O'u*RO'vna~Oj.qOp.qOxYOzSO}VO(RUO~Ow.rO!O.sO~Ov.tOw.rO!O.sO~Oj.uOxYOzSO}VO!P.uO!Q.vO!R.uO(RUO~Oo.wO~O`.xO~P+vO%X%vO%Z%xO!c!bi!g!bi#p!bi#w!bi$`!bi$a!bi$b!bi$c!bi$d!bi%r!bi%s!bi%t!bi'p!bi!d!bir!bit!bi#e!bi~P&HjOt.|O~P`Ow%]O!c'`X!d'`X!g'`Xr'`Xt'`X#p'`X'p'`X~PNfO!c'kO!g'kO!d(]ar(]at(]a~O`/QOb*oO~Ot/RO~P&L{Ot/UO~O%X%vO%Z%xO!c%Wi!g%Wi#p%Wi#w%Wi$`%Wi$a%Wi$b%Wi$c%Wi$d%Wi%r%Wi%s%Wi%t%Wi'p%Wi!d%Wir%Wit%Wi#e%Wi~P&HjO%X%vO%Z%xO!c%Yi!g%Yi#p%Yi#w%Yi$`%Yi$a%Yi$b%Yi$c%Yi$d%Yi%r%Yi%s%Yi%t%Yi'p%Yi!d%Yir%Yit%Yi#e%Yi~P&HjOv$mOw$nO!O$lO%^&[O%z&iO!Q%]i![%]i!c%]i!g%]i!o%]i!x%]i#T%]i#V%]i#X%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'p%]i!d%]ir%]it%]i#e%]i~O%_&[O~P'/nOv$mOw$nO!O$lO%[%wO%z&iO#V'la#p'la%X'la%Z'la%b'la%c'la%d'la%e'la%f'la%g'la%h'la%i'la%j'la%k'la%l'la%n'la%o'la%p'la%q'la%r'la%s'la%t'la&|'la'p'la!d'lar'lat'la#e'la~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O!c'la!g'la#w'la$`'la$a'la$b'la$c'la$d'la~P'3TOv$mOw$nO!O$lO%[%wO%c%zO%d%{O%e%|O%f%}O%z&iO#V'ma#p'ma%X'ma%Z'ma%g'ma%h'ma%i'ma%j'ma%k'ma%l'ma%n'ma%o'ma%p'ma%q'ma%r'ma%s'ma%t'ma&|'ma'p'ma!d'mar'mat'ma#e'ma~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO!c'ma!g'ma#w'ma$`'ma$a'ma$b'ma$c'ma$d'ma~P'6jO%_%]i~P'/nOv$mOw$nO!O$lO!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%z&iO![%]i!c%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'p%]i!d%]ir%]it%]i#e%]i~O!Q%]i!o%]i%`%]i~P':WO!Q&^O!o&^O%`&^O~P':WOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%z&iO!c%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'p%]i!d%]ir%]it%]i#e%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P'=zO%g&SO%h&QO%i&RO%j&`O%k&UO~P'=zOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'p%]i!d%]ir%]it%]i#e%]i~O#V%]i~P'AtO#V&WO~P'AtOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'p%]i!d%]ir%]it%]i#e%]i~O%o%]i~P'EbO%o&dO~P'EbOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%r%]i%s%]i%t%]i'p%]i!d%]ir%]it%]i#e%]i~O%X%]i%Z%]i%q%]i&|%]i~P'IOO%X%vO%Z%xO%q&fO&|&jO~P'IOO%X%vO%Z%xO%r&XO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%s%]i%t%]i'p%]i!d%]ir%]it%]i#e%]i~P&HjO#e/XO~P&L{O`/ZO~O`/ZO~P+vO`/ZOa/[O~P+vO`/^O~Oc/`O'x/_O~O`/^O~P+vO`/^Oa/aO~P+vOc/dO'x/cO~O!x/eO~P+vO`/fO~Oc/hO'x/gO~O`/fO~P+vO`/fOa/iO~P+vO^/kO'{$oO~O_+vO`+wO~O`/oOa/nO~P+vO_+vO`+wO~P+vO_+vO`+wOa/qO~P+vOa/tO~Ot/uO~P&L{Ot/vO~P&L{Ot/wO~P&L{O!c#ma!g#ma!x#ma#w#ma$`#ma$a#ma$b#ma$c#ma$d#ma%X#ma%Z#ma%[#ma%^#ma%_#ma%`#ma%a#ma%b#ma%c#ma%d#ma%e#ma%f#ma%g#ma%h#ma%i#ma%j#ma%k#ma%l#ma%n#ma%o#ma%p#ma%q#ma%r#ma%s#ma%t#ma&|#ma!d#mar#mat#ma#e#ma~P$+xOt/xO~P&L{OQ]OjROkROlRO!X/yO~O!c'kO!g'kO!d(mX~O!d/|O~Oo%TOw#ma#n#ma#p#ma'p#ma~Ow'yO#p'nO'p'oO~OQ#maR#maS#maT#maU#maj#mak#mal#map#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'w#ma(R#ma(`#ma*i#ma!c#ma!g#ma~P('hO!c(wa!g(wa~P%2POp'XO#t0VO~P%-YO!c'kO!g'kO#p)RX'p)RX~O!g0aO~O'q0cO'r$iO's$jO~O!d0dO~O!d0eO~O!e(RO#e#daw#da#p#da'p#da~O!e0gO~Ow'yO#e-YO#p'nO'p'oO~Op,|O~O!c'kO!g'kO#w)Xa$`)Xa$a)Xa$b)Xa$c)Xa$d)Xa#p)Xa'p)Xa~O$g0nO$i0rOQ$eiR$eiS$eiT$eiU$eid$eij$eik$eil$eip$eiw$eix$eiz$ei}$ei!O$ei!P$ei!Q$ei!R$ei!T$ei!X$ei!Y$ei![$ei!^$ei!_$ei!`$ei!a$ei!e$ei!i$ei!l$ei!o$ei!t$ei!v$ei!z$ei!|$ei#O$ei#P$ei#R$ei#T$ei#V$ei#X$ei#[$ei#]$ei#^$ei#_$ei#a$ei#l$ei#p$ei#r$ei#s$ei#w$ei$Q$ei$Z$ei$_$ei$`$ei$a$ei$b$ei$c$ei$d$ei$w$ei$x$ei$y$ei$z$ei${$ei%Q$ei%R$ei%v$ei%w$ei%x$ei%z$ei%|$ei%}$ei&O$ei&P$ei&Q$ei&R$ei&U$ei&V$ei&W$ei&X$ei&Y$ei&`$ei&b$ei&c$ei&d$ei&i$ei&j$ei&l$ei&x$ei&z$ei'O$ei'P$ei'Q$ei'S$ei'T$ei'V$ei'W$ei'X$ei'o$ei'w$ei(R$ei(`$ei)h$ei*i$eit$ei%T$ei%U$ei%V$ei~O$g0nO$i0rOQ$jiR$jiS$jiT$jiU$jid$jij$jik$jil$jip$jiw$jix$jiz$ji}$ji!O$ji!P$ji!Q$ji!R$ji!T$ji!X$ji!Y$ji![$ji!^$ji!_$ji!`$ji!a$ji!e$ji!i$ji!l$ji!o$ji!t$ji!v$ji!z$ji!|$ji#O$ji#P$ji#R$ji#T$ji#V$ji#X$ji#[$ji#]$ji#^$ji#_$ji#a$ji#l$ji#p$ji#r$ji#s$ji#w$ji$Q$ji$Z$ji$_$ji$`$ji$a$ji$b$ji$c$ji$d$ji$w$ji$x$ji$y$ji$z$ji${$ji%Q$ji%R$ji%v$ji%w$ji%x$ji%z$ji%|$ji%}$ji&O$ji&P$ji&Q$ji&R$ji&U$ji&V$ji&W$ji&X$ji&Y$ji&`$ji&b$ji&c$ji&d$ji&i$ji&j$ji&l$ji&x$ji&z$ji'O$ji'P$ji'Q$ji'S$ji'T$ji'V$ji'W$ji'X$ji'o$ji'w$ji(R$ji(`$ji)h$ji*i$jit$ji%T$ji%U$ji%V$ji~O$n(aOQ$kiR$kiS$kiT$kiU$kid$kij$kik$kil$kip$kiw$kix$kiz$ki}$ki!O$ki!P$ki!Q$ki!R$ki!T$ki!X$ki!Y$ki![$ki!^$ki!_$ki!`$ki!a$ki!e$ki!i$ki!l$ki!o$ki!t$ki!v$ki!z$ki!|$ki#O$ki#P$ki#R$ki#T$ki#V$ki#X$ki#[$ki#]$ki#^$ki#_$ki#a$ki#l$ki#p$ki#r$ki#s$ki#w$ki$Q$ki$Z$ki$_$ki$`$ki$a$ki$b$ki$c$ki$d$ki$w$ki$x$ki$y$ki$z$ki${$ki%Q$ki%R$ki%v$ki%w$ki%x$ki%z$ki%|$ki%}$ki&O$ki&P$ki&Q$ki&R$ki&U$ki&V$ki&W$ki&X$ki&Y$ki&`$ki&b$ki&c$ki&d$ki&i$ki&j$ki&l$ki&x$ki&z$ki'O$ki'P$ki'Q$ki'S$ki'T$ki'V$ki'W$ki'X$ki'o$ki'w$ki(R$ki(`$ki)h$ki*i$kit$ki%T$ki%U$ki%V$ki~Oj1OO~Ol1OO#[!SO#]!TO#^!UO#_!VO~O#p'nO'p'oOQ$siR$siS$siT$siU$sid$sij$sik$sil$sip$siw$six$siz$si}$si!O$si!P$si!Q$si!R$si!T$si!X$si!Y$si![$si!^$si!_$si!`$si!a$si!e$si!i$si!l$si!o$si!t$si!v$si!z$si!|$si#O$si#P$si#R$si#T$si#V$si#X$si#[$si#]$si#^$si#_$si#a$si#l$si#p$si#r$si#s$si#w$si$Q$si$Z$si$_$si$`$si$a$si$b$si$c$si$d$si$w$si$x$si$y$si$z$si${$si%Q$si%R$si%v$si%w$si%x$si%z$si%|$si%}$si&O$si&P$si&Q$si&R$si&U$si&V$si&W$si&X$si&Y$si&`$si&b$si&c$si&d$si&i$si&j$si&l$si&x$si&z$si'O$si'P$si'Q$si'S$si'T$si'V$si'W$si'X$si'o$si'w$si(R$si(`$si)h$si*i$sit$si%T$si%U$si%V$si~O$n(aOQ$oiR$oiS$oiT$oiU$oid$oij$oik$oil$oip$oiw$oix$oiz$oi}$oi!O$oi!P$oi!Q$oi!R$oi!T$oi!X$oi!Y$oi![$oi!^$oi!_$oi!`$oi!a$oi!e$oi!i$oi!l$oi!o$oi!t$oi!v$oi!z$oi!|$oi#O$oi#P$oi#R$oi#T$oi#V$oi#X$oi#[$oi#]$oi#^$oi#_$oi#a$oi#l$oi#p$oi#r$oi#s$oi#w$oi$Q$oi$Z$oi$_$oi$`$oi$a$oi$b$oi$c$oi$d$oi$w$oi$x$oi$y$oi$z$oi${$oi%Q$oi%R$oi%v$oi%w$oi%x$oi%z$oi%|$oi%}$oi&O$oi&P$oi&Q$oi&R$oi&U$oi&V$oi&W$oi&X$oi&Y$oi&`$oi&b$oi&c$oi&d$oi&i$oi&j$oi&l$oi&x$oi&z$oi'O$oi'P$oi'Q$oi'S$oi'T$oi'V$oi'W$oi'X$oi'o$oi'w$oi(R$oi(`$oi)h$oi*i$oit$oi%T$oi%U$oi%V$oi~O#p'nO'p'oO~P$1|O$n(aOQ$qiR$qiS$qiT$qiU$qid$qij$qik$qil$qip$qiw$qix$qiz$qi}$qi!O$qi!P$qi!Q$qi!R$qi!T$qi!X$qi!Y$qi![$qi!^$qi!_$qi!`$qi!a$qi!e$qi!i$qi!l$qi!o$qi!t$qi!v$qi!z$qi!|$qi#O$qi#P$qi#R$qi#T$qi#V$qi#X$qi#[$qi#]$qi#^$qi#_$qi#a$qi#l$qi#p$qi#r$qi#s$qi#w$qi$Q$qi$Z$qi$_$qi$`$qi$a$qi$b$qi$c$qi$d$qi$w$qi$x$qi$y$qi$z$qi${$qi%Q$qi%R$qi%v$qi%w$qi%x$qi%z$qi%|$qi%}$qi&O$qi&P$qi&Q$qi&R$qi&U$qi&V$qi&W$qi&X$qi&Y$qi&`$qi&b$qi&c$qi&d$qi&i$qi&j$qi&l$qi&x$qi&z$qi'O$qi'P$qi'Q$qi'S$qi'T$qi'V$qi'W$qi'X$qi'o$qi'w$qi(R$qi(`$qi)h$qi*i$qit$qi%T$qi%U$qi%V$qi~Ol1OO~Ow%]Ov'`X!c'`X!g'`X!x'`X#p'`X#w'`X$`'`X$a'`X$b'`X$c'`X$d'`X%X'`X%Z'`X%['`X%^'`X%_'`X%`'`X%a'`X%b'`X%c'`X%d'`X%e'`X%f'`X%g'`X%h'`X%i'`X%j'`X%k'`X%l'`X%n'`X%o'`X%p'`X%q'`X%r'`X%s'`X%t'`X&|'`X'p'`X!d'`Xr'`Xt'`X#e'`X~PNfO!c'kO!g'kO#p(va'p(va!d(va~Ov(vaw(va!O(va!Q(va![(va!o(va!x(va#T(va#V(va#X(va#w(va$`(va$a(va$b(va$c(va$d(va%X(va%Z(va%[(va%^(va%_(va%`(va%a(va%b(va%c(va%d(va%e(va%f(va%g(va%h(va%i(va%j(va%k(va%l(va%n(va%o(va%p(va%q(va%r(va%s(va%t(va%z(va&|(var(vat(va#e(va~P)0uO!c'kO!g'kOv)TXw)TX!O)TX!Q)TX![)TX!o)TX!x)TX#T)TX#V)TX#X)TX#p)TX#w)TX$`)TX$a)TX$b)TX$c)TX$d)TX%X)TX%Z)TX%[)TX%^)TX%_)TX%`)TX%a)TX%b)TX%c)TX%d)TX%e)TX%f)TX%g)TX%h)TX%i)TX%j)TX%k)TX%l)TX%n)TX%o)TX%p)TX%q)TX%r)TX%s)TX%t)TX%z)TX&|)TX'p)TX!d)TXr)TXt)TX#e)TX~O!c'kO!d1ZO!g'kO~Ov$mOw$nO!O$lO%z&iO!c*[a!g*[a!d*[a~O!Q*[a![*[a!o*[a!x*[a#T*[a#V*[a#X*[a#p*[a#w*[a$`*[a$a*[a$b*[a$c*[a$d*[a%X*[a%Z*[a%[*[a%^*[a%_*[a%`*[a%a*[a%b*[a%c*[a%d*[a%e*[a%f*[a%g*[a%h*[a%i*[a%j*[a%k*[a%l*[a%n*[a%o*[a%p*[a%q*[a%r*[a%s*[a%t*[a&|*[a'p*[ar*[at*[a#e*[a~P)7xOv(]aw(]a!O(]a!Q(]a![(]a!o(]a!x(]a#T(]a#V(]a#X(]a#p(]a#w(]a$`(]a$a(]a$b(]a$c(]a$d(]a%X(]a%Z(]a%[(]a%^(]a%_(]a%`(]a%a(]a%b(]a%c(]a%d(]a%e(]a%f(]a%g(]a%h(]a%i(]a%j(]a%k(]a%l(]a%n(]a%o(]a%p(]a%q(]a%r(]a%s(]a%t(]a%z(]a&|(]a'p(]a#e(]a~P',XO!d1]O~Op5rOt(]P~P#@SOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOv$mOw.QOxXOzSO}VO!O.PO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POo'}X!c'}X!d(]P!g'}X~O!x'}X%X'}X%Z'}X%['}X%^'}X%_'}X%`'}X%a'}X%b'}X%c'}X%d'}X%e'}X%f'}X%g'}X%h'}X%i'}X%j'}X%k'}X%l'}X%n'}X%o'}X%p'}X%q'}X%r'}X%s'}X%t'}X&|'}X~P)>rO!d1bO~Oj1cOp)ZO~O!d1fO~O!d1gO~Ot1hO~P&L{O!c'kO!g'kOr*ZXv*ZXw*ZX!O*ZX!Q*ZX![*ZX!o*ZX!x*ZX#T*ZX#V*ZX#X*ZX%X*ZX%Z*ZX%[*ZX%^*ZX%_*ZX%`*ZX%a*ZX%b*ZX%c*ZX%d*ZX%e*ZX%f*ZX%g*ZX%h*ZX%i*ZX%j*ZX%k*ZX%l*ZX%n*ZX%o*ZX%p*ZX%q*ZX%r*ZX%s*ZX%t*ZX%z*ZX&|*ZXt*ZX#e*ZX#p*ZX'p*ZX!d*ZX~Or1iO~P&L{Oo%TOt1jO!c5QOj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt1jO~P&L{Op)xO~Og1lO'{$oO~Og.kO'{$oO^(Qi~O`1nO~OP1oOp1oO~Ot1pO~Oj1qOp1qOxYOzSO}VO(RUO~Oj1rOxYOzSO}VO!P1rO!Q1sO!R1rO(RUO~Ow1tO!O1uO~Or1vO~O!P1rO~OP1wOp1wO~O`1yO~P+vO!c'`a!d'`a!g'`ar'`at'`a#p'`a#w'`a$`'`a$a'`a$b'`a$c'`a$d'`a'p'`a#e'`a~P%2POv!niv!nqw!niw!nq!O!ni!O!nq!Q!ni!Q!nq![!ni![!nq!c!ni!c!nq!g!ni!g!nq!o!ni!o!nq!x!ni!x!nq#T!ni#T!nq#V!ni#V!nq#X!ni#X!nq#p!ni#p!nq#w!ni#w!nq$`!ni$`!nq$a!ni$a!nq$b!ni$b!nq$c!ni$c!nq$d!ni$d!nq%X!ni%X!nq%Z!ni%Z!nq%[!ni%[!nq%^!ni%^!nq%_!ni%_!nq%`!ni%`!nq%a!ni%a!nq%b!ni%b!nq%c!ni%c!nq%d!ni%d!nq%e!ni%e!nq%f!ni%f!nq%g!ni%g!nq%h!ni%h!nq%i!ni%i!nq%j!ni%j!nq%k!ni%k!nq%l!ni%l!nq%n!ni%n!nq%o!ni%o!nq%p!ni%p!nq%q!ni%q!nq%r!ni%r!nq%s!ni%s!nq%t!ni%t!nq%z!ni%z!nq&|!ni&|!nq'p!ni'p!nq!d!ni!d!nqr!nir!nqt!nit!nq#e!ni#e!nq~O%X%vO%Z%xO!c%Yq!g%Yq#p%Yq#w%Yq$`%Yq$a%Yq$b%Yq$c%Yq$d%Yq%r%Yq%s%Yq%t%Yq'p%Yq!d%Yqr%Yqt%Yq#e%Yq~P&HjO!c&{q!g&{q#p&{q#w&{q$`&{q$a&{q$b&{q$c&{q$d&{q%X&{q%Z&{q%r&{q%s&{q%t&{q'p&{q!d&{qr&{qt&{q#e&{q~P&HjO`1}O~O`1}O~P+vOc2PO'x2OO~O`2QO~O`2QO~P+vO'x2RO~Oc2SO'x2RO~Oc2UO'x2TO~O`2VO~O`2VO~P+vO^2WO~O`2YOa2XO~P+vO`2YO~Oc2]O'x2[O~O`2YO~P+vOa2_O~O!d2aO~O!c'bX!d'bX!g'bX~P$NoO!c'kO!g'kO!d(ma~O!c'kO!g'kO#n2mO#p'nO'p'oO~P$:`O!d2oO~O!e,oO!c'gX!g'gX#p'gX'p'gX~P%-YO!c'kO!g'kO#p)Ra'p)Ra~O!e,oO!iiO#p)RP'p)RP~P%-YO!d,yO#c,zO~O$g0nO$i0rOQ$eqR$eqS$eqT$eqU$eqd$eqj$eqk$eql$eqp$eqw$eqx$eqz$eq}$eq!O$eq!P$eq!Q$eq!R$eq!T$eq!X$eq!Y$eq![$eq!^$eq!_$eq!`$eq!a$eq!e$eq!i$eq!l$eq!o$eq!t$eq!v$eq!z$eq!|$eq#O$eq#P$eq#R$eq#T$eq#V$eq#X$eq#[$eq#]$eq#^$eq#_$eq#a$eq#l$eq#p$eq#r$eq#s$eq#w$eq$Q$eq$Z$eq$_$eq$`$eq$a$eq$b$eq$c$eq$d$eq$w$eq$x$eq$y$eq$z$eq${$eq%Q$eq%R$eq%v$eq%w$eq%x$eq%z$eq%|$eq%}$eq&O$eq&P$eq&Q$eq&R$eq&U$eq&V$eq&W$eq&X$eq&Y$eq&`$eq&b$eq&c$eq&d$eq&i$eq&j$eq&l$eq&x$eq&z$eq'O$eq'P$eq'Q$eq'S$eq'T$eq'V$eq'W$eq'X$eq'o$eq'w$eq(R$eq(`$eq)h$eq*i$eqt$eq%T$eq%U$eq%V$eq~O$g0nO$i0rOQ$jqR$jqS$jqT$jqU$jqd$jqj$jqk$jql$jqp$jqw$jqx$jqz$jq}$jq!O$jq!P$jq!Q$jq!R$jq!T$jq!X$jq!Y$jq![$jq!^$jq!_$jq!`$jq!a$jq!e$jq!i$jq!l$jq!o$jq!t$jq!v$jq!z$jq!|$jq#O$jq#P$jq#R$jq#T$jq#V$jq#X$jq#[$jq#]$jq#^$jq#_$jq#a$jq#l$jq#p$jq#r$jq#s$jq#w$jq$Q$jq$Z$jq$_$jq$`$jq$a$jq$b$jq$c$jq$d$jq$w$jq$x$jq$y$jq$z$jq${$jq%Q$jq%R$jq%v$jq%w$jq%x$jq%z$jq%|$jq%}$jq&O$jq&P$jq&Q$jq&R$jq&U$jq&V$jq&W$jq&X$jq&Y$jq&`$jq&b$jq&c$jq&d$jq&i$jq&j$jq&l$jq&x$jq&z$jq'O$jq'P$jq'Q$jq'S$jq'T$jq'V$jq'W$jq'X$jq'o$jq'w$jq(R$jq(`$jq)h$jq*i$jqt$jq%T$jq%U$jq%V$jq~O$n(aOQ$kqR$kqS$kqT$kqU$kqd$kqj$kqk$kql$kqp$kqw$kqx$kqz$kq}$kq!O$kq!P$kq!Q$kq!R$kq!T$kq!X$kq!Y$kq![$kq!^$kq!_$kq!`$kq!a$kq!e$kq!i$kq!l$kq!o$kq!t$kq!v$kq!z$kq!|$kq#O$kq#P$kq#R$kq#T$kq#V$kq#X$kq#[$kq#]$kq#^$kq#_$kq#a$kq#l$kq#p$kq#r$kq#s$kq#w$kq$Q$kq$Z$kq$_$kq$`$kq$a$kq$b$kq$c$kq$d$kq$w$kq$x$kq$y$kq$z$kq${$kq%Q$kq%R$kq%v$kq%w$kq%x$kq%z$kq%|$kq%}$kq&O$kq&P$kq&Q$kq&R$kq&U$kq&V$kq&W$kq&X$kq&Y$kq&`$kq&b$kq&c$kq&d$kq&i$kq&j$kq&l$kq&x$kq&z$kq'O$kq'P$kq'Q$kq'S$kq'T$kq'V$kq'W$kq'X$kq'o$kq'w$kq(R$kq(`$kq)h$kq*i$kqt$kq%T$kq%U$kq%V$kq~O$n(aOQ$oqR$oqS$oqT$oqU$oqd$oqj$oqk$oql$oqp$oqw$oqx$oqz$oq}$oq!O$oq!P$oq!Q$oq!R$oq!T$oq!X$oq!Y$oq![$oq!^$oq!_$oq!`$oq!a$oq!e$oq!i$oq!l$oq!o$oq!t$oq!v$oq!z$oq!|$oq#O$oq#P$oq#R$oq#T$oq#V$oq#X$oq#[$oq#]$oq#^$oq#_$oq#a$oq#l$oq#p$oq#r$oq#s$oq#w$oq$Q$oq$Z$oq$_$oq$`$oq$a$oq$b$oq$c$oq$d$oq$w$oq$x$oq$y$oq$z$oq${$oq%Q$oq%R$oq%v$oq%w$oq%x$oq%z$oq%|$oq%}$oq&O$oq&P$oq&Q$oq&R$oq&U$oq&V$oq&W$oq&X$oq&Y$oq&`$oq&b$oq&c$oq&d$oq&i$oq&j$oq&l$oq&x$oq&z$oq'O$oq'P$oq'Q$oq'S$oq'T$oq'V$oq'W$oq'X$oq'o$oq'w$oq(R$oq(`$oq)h$oq*i$oqt$oq%T$oq%U$oq%V$oq~O$n(aOQ$qqR$qqS$qqT$qqU$qqd$qqj$qqk$qql$qqp$qqw$qqx$qqz$qq}$qq!O$qq!P$qq!Q$qq!R$qq!T$qq!X$qq!Y$qq![$qq!^$qq!_$qq!`$qq!a$qq!e$qq!i$qq!l$qq!o$qq!t$qq!v$qq!z$qq!|$qq#O$qq#P$qq#R$qq#T$qq#V$qq#X$qq#[$qq#]$qq#^$qq#_$qq#a$qq#l$qq#p$qq#r$qq#s$qq#w$qq$Q$qq$Z$qq$_$qq$`$qq$a$qq$b$qq$c$qq$d$qq$w$qq$x$qq$y$qq$z$qq${$qq%Q$qq%R$qq%v$qq%w$qq%x$qq%z$qq%|$qq%}$qq&O$qq&P$qq&Q$qq&R$qq&U$qq&V$qq&W$qq&X$qq&Y$qq&`$qq&b$qq&c$qq&d$qq&i$qq&j$qq&l$qq&x$qq&z$qq'O$qq'P$qq'Q$qq'S$qq'T$qq'V$qq'W$qq'X$qq'o$qq'w$qq(R$qq(`$qq)h$qq*i$qqt$qq%T$qq%U$qq%V$qq~Ol3RO~O!d3TO~Ov'hX!c'hX!g'hX!x'hX#p'hX#w'hX$`'hX$a'hX$b'hX$c'hX$d'hX%X'hX%Z'hX%['hX%^'hX%_'hX%`'hX%a'hX%b'hX%c'hX%d'hX%e'hX%f'hX%g'hX%h'hX%i'hX%j'hX%k'hX%l'hX%n'hX%o'hX%p'hX%q'hX%r'hX%s'hX%t'hX&|'hX'p'hX!d'hXr'hXt'hX#e'hX~P!-}O!c'kO!g'kOv)Taw)Ta!O)Ta!Q)Ta![)Ta!o)Ta!x)Ta#T)Ta#V)Ta#X)Ta#p)Ta#w)Ta$`)Ta$a)Ta$b)Ta$c)Ta$d)Ta%X)Ta%Z)Ta%[)Ta%^)Ta%_)Ta%`)Ta%a)Ta%b)Ta%c)Ta%d)Ta%e)Ta%f)Ta%g)Ta%h)Ta%i)Ta%j)Ta%k)Ta%l)Ta%n)Ta%o)Ta%p)Ta%q)Ta%r)Ta%s)Ta%t)Ta%z)Ta&|)Ta'p)Ta!d)Tar)Tat)Ta#e)Ta~Ot3UO~Ov$mOw$nO!O$lO!Q*Zi![*Zi!c*Zi!g*Zi!o*Zi!x*Zi#T*Zi#V*Zi#X*Zi#p*Zi#w*Zi$`*Zi$a*Zi$b*Zi$c*Zi$d*Zi%X*Zi%Z*Zi%[*Zi%^*Zi%_*Zi%`*Zi%a*Zi%b*Zi%c*Zi%d*Zi%e*Zi%f*Zi%g*Zi%h*Zi%i*Zi%j*Zi%k*Zi%l*Zi%n*Zi%o*Zi%p*Zi%q*Zi%r*Zi%s*Zi%t*Zi%z*Zi&|*Zi'p*Zi!d*Zir*Zit*Zi#e*Zi~O!d3WO~O!c'kO!g'kOr(]X~P%2PO!c'kO!g'kOt(]X~P%2PO!d3XO~O!e(ROv&nqw&nq!O&nq!Q&nq![&nq!c&nq!g&nq!o&nq!x&nq#T&nq#V&nq#X&nq#p&nq#w&nq$`&nq$a&nq$b&nq$c&nq$d&nq%X&nq%Z&nq%[&nq%^&nq%_&nq%`&nq%a&nq%b&nq%c&nq%d&nq%e&nq%f&nq%g&nq%h&nq%i&nq%j&nq%k&nq%l&nq%n&nq%o&nq%p&nq%q&nq%r&nq%s&nq%t&nq%z&nq&|&nq'p&nq!d&nqr&nqt&nq#e&nq~O!e(ROv&kyw&ky!O&ky!Q&ky![&ky!c&ky!g&ky!o&ky!x&ky#T&ky#V&ky#X&ky#p&ky#w&ky$`&ky$a&ky$b&ky$c&ky$d&ky%X&ky%Z&ky%[&ky%^&ky%_&ky%`&ky%a&ky%b&ky%c&ky%d&ky%e&ky%f&ky%g&ky%h&ky%i&ky%j&ky%k&ky%l&ky%n&ky%o&ky%p&ky%q&ky%r&ky%s&ky%t&ky%z&ky&|&ky'p&ky!d&kyr&kyt&ky#e&ky~Ot3_O~Or3`O~O!P3aO~Oj3bOp3bOxYOzSO}VO(RUO~Oj3aOxYOzSO}VO!P3aO!Q3cO!R3aO(RUO~Ov!fiw!fi!O!fi!Q!fi![!fi!o!fi!x!fi#T!fi#V!fi#X!fi%X!fi%Z!fi%[!fi%^!fi%_!fi%`!fi%a!fi%b!fi%c!fi%d!fi%e!fi%f!fi%g!fi%h!fi%i!fi%j!fi%k!fi%l!fi%n!fi%o!fi%p!fi%q!fi%r!fi%s!fi%t!fi%z!fi&|!fi~O!c!fi!g!fi#p#gi'p#gi!d#gi~P+8gO!c&{y!g&{y#p&{y#w&{y$`&{y$a&{y$b&{y$c&{y$d&{y%X&{y%Z&{y%r&{y%s&{y%t&{y'p&{y!d&{yr&{yt&{y#e&{y~P&HjO'x3dO~Oc3eO'x3dO~O'x3fO~O'x3gO~Oc3hO'x3gO~O`3iO~Oc3kO'x3jO~O`3iO~P+vO`3iOa3lO~P+vO`3nO~Oa3oO~O!c'kO!g'kO#p'nO'p'oO~P$:`O#p'nO'p'oO~P&L{O!d3{O~O$n(aOQ$qyR$qyS$qyT$qyU$qyd$qyj$qyk$qyl$qyp$qyw$qyx$qyz$qy}$qy!O$qy!P$qy!Q$qy!R$qy!T$qy!X$qy!Y$qy![$qy!^$qy!_$qy!`$qy!a$qy!e$qy!i$qy!l$qy!o$qy!t$qy!v$qy!z$qy!|$qy#O$qy#P$qy#R$qy#T$qy#V$qy#X$qy#[$qy#]$qy#^$qy#_$qy#a$qy#l$qy#p$qy#r$qy#s$qy#w$qy$Q$qy$Z$qy$_$qy$`$qy$a$qy$b$qy$c$qy$d$qy$w$qy$x$qy$y$qy$z$qy${$qy%Q$qy%R$qy%v$qy%w$qy%x$qy%z$qy%|$qy%}$qy&O$qy&P$qy&Q$qy&R$qy&U$qy&V$qy&W$qy&X$qy&Y$qy&`$qy&b$qy&c$qy&d$qy&i$qy&j$qy&l$qy&x$qy&z$qy'O$qy'P$qy'Q$qy'S$qy'T$qy'V$qy'W$qy'X$qy'o$qy'w$qy(R$qy(`$qy)h$qy*i$qyt$qy%T$qy%U$qy%V$qy~O!d4RO~P&L{O!d4SO~Or*`iv*`iw*`i!O*`i!Q*`i![*`i!c!fi!g!fi!o*`i!x*`i#T*`i#V*`i#X*`i%X*`i%Z*`i%[*`i%^*`i%_*`i%`*`i%a*`i%b*`i%c*`i%d*`i%e*`i%f*`i%g*`i%h*`i%i*`i%j*`i%k*`i%l*`i%n*`i%o*`i%p*`i%q*`i%r*`i%s*`i%t*`i%z*`i&|*`it*`i#e*`i#p*`i'p*`i!d*`i~Or*giv*giw*gi!O*gi!Q*gi![*gi!c!fi!g!fi!o*gi!x*gi#T*gi#V*gi#X*gi%X*gi%Z*gi%[*gi%^*gi%_*gi%`*gi%a*gi%b*gi%c*gi%d*gi%e*gi%f*gi%g*gi%h*gi%i*gi%j*gi%k*gi%l*gi%n*gi%o*gi%p*gi%q*gi%r*gi%s*gi%t*gi%z*gi&|*git*gi#e*gi#p*gi'p*gi!d*gi~Or4TO~Ot4UO~O!P4VO~O'x4WO~O'x4XO~Oc4ZO'x4YO~O`4[O~O`4[O~P+vOc4^O'x4]O~O`4_O~O$n(aOQ$q!RR$q!RS$q!RT$q!RU$q!Rd$q!Rj$q!Rk$q!Rl$q!Rp$q!Rw$q!Rx$q!Rz$q!R}$q!R!O$q!R!P$q!R!Q$q!R!R$q!R!T$q!R!X$q!R!Y$q!R![$q!R!^$q!R!_$q!R!`$q!R!a$q!R!e$q!R!i$q!R!l$q!R!o$q!R!t$q!R!v$q!R!z$q!R!|$q!R#O$q!R#P$q!R#R$q!R#T$q!R#V$q!R#X$q!R#[$q!R#]$q!R#^$q!R#_$q!R#a$q!R#l$q!R#p$q!R#r$q!R#s$q!R#w$q!R$Q$q!R$Z$q!R$_$q!R$`$q!R$a$q!R$b$q!R$c$q!R$d$q!R$w$q!R$x$q!R$y$q!R$z$q!R${$q!R%Q$q!R%R$q!R%v$q!R%w$q!R%x$q!R%z$q!R%|$q!R%}$q!R&O$q!R&P$q!R&Q$q!R&R$q!R&U$q!R&V$q!R&W$q!R&X$q!R&Y$q!R&`$q!R&b$q!R&c$q!R&d$q!R&i$q!R&j$q!R&l$q!R&x$q!R&z$q!R'O$q!R'P$q!R'Q$q!R'S$q!R'T$q!R'V$q!R'W$q!R'X$q!R'o$q!R'w$q!R(R$q!R(`$q!R)h$q!R*i$q!Rt$q!R%T$q!R%U$q!R%V$q!R~Or4iO~O'x4jO~Oc4kO'x4jO~O'x4lO~Oc4mO'x4lO~O$n(aOQ$q!ZR$q!ZS$q!ZT$q!ZU$q!Zd$q!Zj$q!Zk$q!Zl$q!Zp$q!Zw$q!Zx$q!Zz$q!Z}$q!Z!O$q!Z!P$q!Z!Q$q!Z!R$q!Z!T$q!Z!X$q!Z!Y$q!Z![$q!Z!^$q!Z!_$q!Z!`$q!Z!a$q!Z!e$q!Z!i$q!Z!l$q!Z!o$q!Z!t$q!Z!v$q!Z!z$q!Z!|$q!Z#O$q!Z#P$q!Z#R$q!Z#T$q!Z#V$q!Z#X$q!Z#[$q!Z#]$q!Z#^$q!Z#_$q!Z#a$q!Z#l$q!Z#p$q!Z#r$q!Z#s$q!Z#w$q!Z$Q$q!Z$Z$q!Z$_$q!Z$`$q!Z$a$q!Z$b$q!Z$c$q!Z$d$q!Z$w$q!Z$x$q!Z$y$q!Z$z$q!Z${$q!Z%Q$q!Z%R$q!Z%v$q!Z%w$q!Z%x$q!Z%z$q!Z%|$q!Z%}$q!Z&O$q!Z&P$q!Z&Q$q!Z&R$q!Z&U$q!Z&V$q!Z&W$q!Z&X$q!Z&Y$q!Z&`$q!Z&b$q!Z&c$q!Z&d$q!Z&i$q!Z&j$q!Z&l$q!Z&x$q!Z&z$q!Z'O$q!Z'P$q!Z'Q$q!Z'S$q!Z'T$q!Z'V$q!Z'W$q!Z'X$q!Z'o$q!Z'w$q!Z(R$q!Z(`$q!Z)h$q!Z*i$q!Zt$q!Z%T$q!Z%U$q!Z%V$q!Z~O!d4rO~P&L{O'x4sO~O'x4tO~O!d4uO~P&L{Oj&xOw&yO!T5OO~OR6hOS6tOT4zOp5RO!Q5PO!Y6dO!o6eO%v5PO%w5PO%z6gO~P#/zOR6hOS6tOT4zOp5RO!Q5PO!Y6dO!o6eO%v5PO%w5PO%z6gO~P#8OOp5pO~P$!SOj)nOw)oO!T5OO~Oo%TO!c5QOj&oXp&oXr#YXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YXt#YX#e#YX#p#YX'p#YX!d#YX~P!NRO#p(]X#w(]X$`(]X$a(]X$b(]X$c(]X$d(]X'p(]Xr(]Xt(]X#e(]X~P$1|O%X5wO~P#JWOr%]av%]aw%]a!O%]a!Q%]a![%]a!o%]a!x%]a#T%]a#V%]a#X%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]at%]a#e%]a#p%]a'p%]a!d%]a~O%b5WO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P,4iO%g5YO%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P,4iOv$mOw$nO!O$lO!Q)UX![)UX!c)UX!g)UX!o)UX!x)UX#T)UX#V)UX#X)UX#p)UX#w)UX$`)UX$a)UX$b)UX$c)UX$d)UX%X)UX%Z)UX%[)UX%^)UX%_)UX%`)UX%a)UX%b)UX%c)UX%d)UX%e)UX%f)UX%g)UX%h)UX%i)UX%j)UX%k)UX%l)UX%n)UX%o)UX%p)UX%q)UX%r)UX%s)UX%t)UX%z)UX&|)UX'p)UX!d)UXr)UXt)UX#e)UX~Ov$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#V&WO#X5]O%X5TO%Z5UO%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%n5cO%o5dO%p5eO%q5fO%z&iO&|6kO~Or%ua%r%ua%s%ua%t%uat%ua#e%ua#p%ua'p%ua!d%ua~P,;eO!c'kO!g'kO#p(vX'p(vX!d(vX~P%2POv$mOw$nO!O$lOQ*dXR*dXS*dXT*dXU*dXj*dXk*dXl*dXo'}Xp*dXx*dXz*dX}*dX!P*dX!Q'}X!Q*dX!R*dX!T*dX!X*dX!Y*dX!['}X![*dX!^*dX!_*dX!`*dX!a*dX!c'}X!d'}X!d*dX!e*dX!g'}X!i*dX!l*dX!o'}X!o*dX!t*dX!v*dX!x'}X!z*dX!|*dX#O*dX#P*dX#R*dX#T'}X#T*dX#V'}X#V*dX#X'}X#X*dX#[*dX#]*dX#^*dX#_*dX#a*dX%X'}X%Z'}X%['}X%^'}X%_'}X%`'}X%a'}X%b'}X%c'}X%d'}X%e'}X%f'}X%g'}X%h'}X%i'}X%j'}X%k'}X%l'}X%n'}X%o'}X%p'}X%q'}X%r'}X%s'}X%t'}X%v*dX%w*dX%x*dX%z'}X%z*dX%|*dX%}*dX&O*dX&P*dX&Q*dX&R*dX&U*dX&V*dX&W*dX&X*dX&Y*dX&`*dX&b*dX&c*dX&d*dX&i*dX&j*dX&l*dX&x*dX&z*dX&|'}X'O*dX'P*dX'Q*dX'S*dX'T*dX'V*dX'W*dX'X*dX'w*dX(R*dX(`*dX*i*dX~Or'}Xr*dX!x*dX%X*dX%Z*dX%[*dX%^*dX%_*dX%`*dX%a*dX%b*dX%c*dX%d*dX%e*dX%f*dX%g*dX%h*dX%i*dX%j*dX%k*dX%l*dX%n*dX%o*dX%p*dX%q*dX%r*dX%s*dX%t*dX&|*dXt'}Xt*dX#e'}X#e*dX#p'}X#p*dX'p'}X'p*dX~P,>uOr(]P!x(]P%X(]P%Z(]P%[(]P%^(]P%_(]P%`(]P%a(]P%b(]P%c(]P%d(]P%e(]P%f(]P%g(]P%h(]P%i(]P%j(]P%k(]P%l(]P%n(]P%o(]P%p(]P%q(]P%r(]P%s(]P%t(]P&|(]Pt(]P#e(]P#p(]P'p(]P~P)>rO!Q5^O![5_O!o5^O!x5]O#T5]O#X5]O%^5[O%_5[O%`5^O%a5_O%b5WO%g5YO%j5`O~P&<qO!c5QO~P&@]Ov$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#V&WO#X5]O%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%n5cO%o5dO%p5eO%q5fO%z&iO&|6kO~Or&ya%X&ya%Z&ya%r&ya%s&ya%t&yat&ya#e&ya#p&ya'p&ya!d&ya~P,LdOo%TOt.iO!c%SOj&oXp&oXv#mXw&rX!g#YX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROr!bi%r!bi%s!bi%t!bit!bi#e!bi#p!bi'p!bi!d!bi~P,;eOr%Wi%r%Wi%s%Wi%t%Wit%Wi#e%Wi#p%Wi'p%Wi!d%Wi~P,;eOr%Yi%r%Yi%s%Yi%t%Yit%Yi#e%Yi#p%Yi'p%Yi!d%Yi~P,;eOv$mOw$nO!O$lO%^5[O%z&iOr%]i!Q%]i![%]i!o%]i!x%]i#T%]i#V%]i#X%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'p%]i!d%]i~O%_5[O~P-%sO!Q5^O![5_O!o5^O!x5]O#T5]O#X5]O%^5[O%_5[O%`5^O%a5_O~P'3TO!Q5^O![5_O!o5^O!x5]O#T5]O#X5]O%^5[O%_5[O%`5^O%a5_O%b5WO~P'6jO%_%]i~P-%sOv$mOw$nO!O$lO!x5]O#T5]O#X5]O%[%wO%^5[O%_5[O%z&iOr%]i![%]i#V%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'p%]i!d%]i~O!Q%]i!o%]i%`%]i~P-*bO!Q5^O!o5^O%`5^O~P-*bOv$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#X5]O%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%z&iOr%]i#V%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'p%]i!d%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P--lO%g5YO%h&QO%i&RO%j5`O%k&UO~P--lOv$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#X5]O%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%z&iOr%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'p%]i!d%]i~O#V%]i~P-0|O#V&WO~P-0|Ov$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#V&WO#X5]O%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%n5cO%z&iOr%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'p%]i!d%]i~O%o%]i~P-4QO%o5dO~P-4QOv$mOw$nO!O$lO!Q5^O![5_O!o5^O!x5]O#T5]O#V&WO#X5]O%[%wO%^5[O%_5[O%`5^O%a5_O%b5WO%c%zO%d%{O%e%|O%f%}O%g5YO%h&QO%i&RO%j5`O%k&UO%l&VO%n5cO%o5dO%p5eO%z&iOr%]i%r%]i%s%]i%t%]it%]i#e%]i#p%]i'p%]i!d%]i~O%X%]i%Z%]i%q%]i&|%]i~P-7UO%X5TO%Z5UO%q5fO&|6kO~P-7UO%r&XOr%]i%s%]i%t%]it%]i#e%]i#p%]i'p%]i!d%]i~P,;eO!d1{O~O!c*[a!d*[a!g*[a~P%2PO!d3[O~O!d3]O~Or%Yq%r%Yq%s%Yq%t%Yqt%Yq#e%Yq#p%Yq'p%Yq!d%Yq~P,;eOr&{q%X&{q%Z&{q%r&{q%s&{q%t&{qt&{q#e&{q#p&{q'p&{q!d&{q~P,LdO!c#gi!g#gi~P+8gOr#giv#giw#gi!O#gi!Q#gi![#gi!c!fi!g!fi!o#gi!x#gi#T#gi#V#gi#X#gi%X#gi%Z#gi%[#gi%^#gi%_#gi%`#gi%a#gi%b#gi%c#gi%d#gi%e#gi%f#gi%g#gi%h#gi%i#gi%j#gi%k#gi%l#gi%n#gi%o#gi%p#gi%q#gi%r#gi%s#gi%t#gi%z#gi&|#git#gi#e#gi#p#gi'p#gi!d#gi~Or&{y%X&{y%Z&{y%r&{y%s&{y%t&{yt&{y#e&{y#p&{y'p&{y!d&{y~P,LdO!c5QO~P?lOQ]OR6hOS6tOT4zOU$OOjQOkROlROp5ROxXOzSO}VO!OmO!P$eO!Q5PO!R$eO!T$fO!X$eO!Y6dO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6eO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5PO%w5PO%x#XO%z6gO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~Ow%rO~P-A_OQ]OR6hOS6tOT4zOU$OOjQOkROlROp5ROw%]OxXOzSO}VO!OmO!P$eO!Q5PO!R$eO!T$fO!X$eO!Y6dO![^O!^`O!_aO!`bO!acO!iiO!llO!o6eO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5PO%w5PO%x#XO%z6gO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~O!ehOr&SXv&SX!x&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SXt&SX#e&SX#p&SX'p&SX!d&SX~P-FoOQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$POr(]Pv(]Pw(]P!O(]P!Q(]P!o(]P!x(]P#T(]P#V(]P#X(]P%X(]P%Z(]P%[(]P%^(]P%_(]P%`(]P%a(]P%b(]P%c(]P%d(]P%e(]P%f(]P%g(]P%h(]P%i(]P%j(]P%k(]P%l(]P%n(]P%o(]P%p(]P%q(]P%r(]P%s(]P%t(]P%z(]P&|(]Pt(]P#e(]P#p(]P'p(]P!d(]P~Oj5mOp({O!e6nO&e(}O&f)OO&g)PO~P-NZOj5nOp%XO!e6oO~P-NZO#e6WO~P#JWO#e6_O~P&L{O!e6xO~P%'pO!d6bO~O!d6aO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6xO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'wvO(RUO(`qO*i$PO~OwnO~P.)fOk6wO!e)fO#R!OO~O#tx#n!R!P%wp!Yjkl!X#c!l%Z%`%z!l!Q!o%^!T#R#T#V#X!x!O%^~",
  goto: "&1T*zPPPPPPPPPPPPPPPPPPPPPPPP*{*{PPP+x,nPP-dP-gP-gPPP.]P.].]PPPPP1sP6W9e<rPP<uP@VPPPP@VPPPC_PFiPIy@VPJPM^P@V@V@V@VP@VP@VP@VP@VP@VPP!!nP!'RP@VP@VP!*a@VPPPPJPP!-lP!-yP!.d!/[!1sP!2U!5^P!5gP!9VP!5^PPP!:b!5^P!5^P!5^P!5^P!5^!5^P!5^P!5^PPP!5^!5^P!;W!5^!;^PPPPPP!5^!;kP!;qP!5^!5^!;}!<WP!5^!5^!5^P!5^!5^!<y!5^PPPPP!5^!5^!5^!5^PP!=SPPP@VP@VPP@VPPPPPPPPPPPPPPP!=XPPPPPPP@VPPP@VP@VPPPPPP@V@VPPPPP@V!>l@V!Av@VP@VPPPPPP@VPP@VP!EO@V!EV@V@V!Hb@V@V@V!Kj@VP@VP@VP@VPPP@VPP@VPPPP!Nt#!^#!d#!w#!}##U##m##s##y#$z#%R#%o#%u#%{#&Z#&e#&q#&w#(j#*XPPPPPPPPPPPPP#*_#+T#/Y#2|#6dP#7P#:g#Aa#Dt#Hb#Hb#Hb#Kj#Nr$$O$%g$&wP$*T$-]$0e$3m$6u$7X$7X$:a$=w$=w$=w$=w$AT$AW$A^$Do$Dr$EP$EY$H_$Hh$Hq$IT$IX$Io$Ir$Iv$I|$JQ$JZ$J^$J^Is$Ja$Jh$Jt$Ke$Kn$Kw$Kz$LX$Lk$MQ$Mg$Mg$M|$NS$NY$Ng$Ng$Ng$Ng$NgP$Ns$Ns$N|% R% R% R% W%!{%!{%!{%!{%$l%$l%&X%'r%)X%*Q%*Q%*w%.R%.R%.R%.R%.R%.R%1Z%4e%4e%4e%4e%4e%7m%:w%:{%;U%;U%;U%>`%>d%>d%>d%>m%>u%>u%BP%BTP%Ea%Hk%Ku& P& P& P&$X&$]&'e&'e&*m&*p&-x&-x&-x&1QQ$kP!f$xUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3mT,v'n,w!g$xUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3m!g$tUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3mR1x.w!g$wUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3m'yYOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*T*W*i*k+S+f,a,d,o-d-s-w-x-}.P.Q.S.U.Z.r.s/X0V0Z0^0a1S1V1[1e1t1u2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y!f$xUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3mS&x!O4xQ&z!PQ&|!QQ'Q!RS)n$f5OT)y$m$|'g]Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,V,a-d-s-w-x-}.P.Q.S.U.Z/X/z0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y'g[Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,V,a-d-s-w-x-}.P.Q.S.U.Z/X/z0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR*b%P'm_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a,d,o-d-s-w-x-}.P.Q.S.U.Z/X0V0Z0^0a1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y'akOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y'`kOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ,q'hR2r0aQ%ajR*r%b'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yV(u#q(w4y'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yU(u#q(w4yR,m'e'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y!f$xUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3mQ)e$ZQ)h$_Q)k$dQ.[)fQ.])iQ.^)lR6w6z'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ)k$dR.^)l'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR,l'eS'{!g%_Q-U'wQ0P,YR0h-O!P't!g%_'u'w'{'},Y-R-S-U-W-Z-]/}0P0R0j0l0m2e2f2h3qS'|!g%_S-Q'u'}Q-V'wU0Q,Y-S-WQ0f,|S0k-R-]U2d/}0R0mQ2s0jS3r2e2hR4`3qt'r!g%_'u'w'},Y,|-R-S-W-]/}0R0j0m2e2h3qQ(S!qQ(T!rQ(U!sQ(Z!uQ(]!vW(q#k#l6t6uS(s#n6vS)y$m$|Q*c%RQ*}%tQ,`'YQ,c'ZQ-b(VQ-c(WS-e(X(^Q.V)[Q.g)yQ0U,aQ0}-fS1d.Z6qQ2k0VQ2u0oQ3Q1OQ3Y1cQ3Z1eQ3^1kS3t2l2mQ4O3RR4c3uS'}!g%_Q-R'uQ-W'wS0R,Y-SR2e/}^!wOn$h%W%p'y*iS'z!g%_Q(Y!tQ(h#PU(r#l#|6uW)Q#u(|6i6nS)X#x6jS)a$Q4{S)b$S4|Q,['WQ-T'wQ-X'xS-['{'|Q-_(SQ-`(TQ-a(UQ-k(ZQ-n(]Q-p(bS.U)V6oU0O,Y-U-VQ0S,]S0i-Q-ZQ0x-bQ0y-cQ0|-eU2g0P0Q0lQ2t0kQ2x0sQ3P0}S3p2d2fQ3x2sQ3y2uQ3}3QQ4Q3TQ4a3rQ4e3{Q4g4OQ4n4`Q4v4rR4w4u_#WOn$h%W%p'y*i'[#mOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ'P!QQ'W![S'Y!_!`Q'j!cQ)[#zQ0V,dR1c.X#c'o!e!w!y%i%m%u'W'Y'b'c'j'w(Y([(d*g*x*y,Y,],`,a,e,g,i,m,q-U-V-d-j-l-m/T0P0Q0U0V0l0z0{2d2f2k2l2m2n2r3S3r3t3u3z4`4cW(q#k#l6t6uS(s#n6vQ*}%tQ,`'YQ0U,aS1d.Z6qQ2k0VQ3Z1eS3t2l2mR4c3uQ'w!gR,Y'US!pO$hU%in%p'yT*g%W*iX0p-_-`0q0uQ0t-_Q0v-`Q2w0qR2y0u_!tOn$h%W%p'y*iQ(d!wQ-j(YQ0w-aQ1R-kQ1U-nQ2z0xQ2{0yQ3O0|Q3|3PQ4f3}R4q4g_!yOn$h%W%p'y*iV%nn%p'y![&bp%Y%e%g(O(k(o)d*d+P+Q+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!c5b)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5q5s5t5u6Q6R6S6T6U6V6^6`6c6p%S#nOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6v$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k']#oOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yS)y$m$|R1k.h'[#zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR.X)]']#|Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y%S$QOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X4{$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6kQ$vUQ&lqQ)s$jr*Z$v&l)s*]+j+n+q+t+z.y/]/b/j/p/r2Z3mQ*]$zQ+j&mQ+n&oQ+q&qQ+t&rQ+z&tQ.y*^Q/]+kQ/b+oQ/j+uQ/p+yQ/r+{Q2Z/mR3m2^Q*S$sR.p*Sb$pTWjsuxz}+wS)}$p.jT.j*O.lQ.l*OR1m.lS%OZ,TR*`%O[*l%Y%e-l0z1_1`Q-t(oQ-{5SW/O*l-t-{/VR/V5kQ*p%`R/P*pQ/{,WR2c/{S'u!g%_f-P'u-S-Z-]/}0j0l0m2f2h3qQ-S'wQ-Z'{Q-]'}Q/},YQ0j-RQ0l-UQ0m-WQ2f0PQ2h0RR3q2eS%pn'yR*z%pd%Uf%X'i({)c){.e5R5p5rW*f%U,R,Z,^S,R'O)ZQ,Z'VR,^'XQ,w'nR0b,wQ0_,pR2q0_Q'm!dU,u'm-^1WQ-^(PR1W-uQ0q-_Q0u-`T2v0q0u^!xOn$h%W%p'y*iR(f!xQ*i%WR.{*i!f&Pp%Y%e%g(O(k(o)^)d*d+P+Q+V+[+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6ZS+U&P5X!m5X)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5o5q5s5t5u5y5}6O6P6Q6R6S6T6U6V6^6`6c6p!b&Tp%Y%e%g(O(k(o)^)d*d+P+Q+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6ZS+W&T5Z!i5Z)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5o5q5s5t5u6O6P6Q6R6S6T6U6V6^6`6c6pQ$hOR)p$h!g$yUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3m'`ZOhmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y!f$xUq$j$v$z&l&m&o&q&r&t)s*]*^+j+k+n+o+q+t+u+y+z+{.y/]/b/j/m/p/r2Z2^3mV,T'S,V/z'l_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a,d,o-d-s-w-x-}.P.Q.S.U.Z/X0V0Z0^0a1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ.q*TQ.u*WQ1q.rQ1r.sQ3a1uR3b1t'yTOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*T*W*i*k+S+f,a,d,o-d-s-w-x-}.P.Q.S.U.Z.r.s/X0V0Z0^0a1S1V1[1e1t1u2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ$rTQ${WQ%bjQ&nsQ&puQ&sxQ&uzQ&w}R/l+w'yWOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*T*W*i*k+S+f,a,d,o-d-s-w-x-}.P.Q.S.U.Z.r.s/X0V0Z0^0a1S1V1[1e1t1u2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y[pO$h%W%p'y*iQ%Yhr%em%Z%]%r'q(R(|)V-w-}.S.U6l6n6o6x6yQ%gnW%so#Y5P6eS(O!j'lQ(k#ZS(l#[6g`(o#k#l#n.Z6q6t6u6vQ)^#}Q)d$UQ)u$lQ)|$nQ*d%SQ*s%dQ+P%vQ+Q%xS+R%y&]Q+T&OQ+V&SQ+X&[Q+Y&^Q+Z&_Q+[&`Q+]&aQ+^&bQ+_&cQ+`&dQ+a&eQ+b&fQ+c&gQ+d&hQ+e&jQ,O&yQ,P&{Q,Q&}Q,S'RQ,b'ZQ-l([Q-z(yQ._)oQ.d)vQ.f)wS.}*k-sQ/W+SQ/Y+fQ0z-dS1Y-x6YQ1_.PQ1`.QQ1|/XQ2n0ZQ3S1SQ3V1[Q3z2|Q4h4PQ4p4d`5S#u#x)T)U)X5n6i6j`5i#d$Q$S(r1V4{4|6hQ5j6f`5k%t'Y,a0V1e2l2m3uQ5o4zQ5q4}Q5s5QQ5t5TQ5u5US5v5V5]Q5x5WQ5y5YQ5z5[Q5{5^Q5|5_Q5}5`Q6O5aQ6P5bQ6Q5cQ6R5dQ6S5eQ6T5fQ6U5gQ6V5hQ6Z6mQ6^5wQ6`6WQ6c6_R6p6k'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yS'T!X%^S,U'S/zR/y,V'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ,e'^Q,i'bQ,l'eU,n'h0^0aQ0V,dR0],o']dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yT,f'`'bS%[h%ZS%fm.PU%hn%].QS)R#u6iS)W#x6jQ*|%rW,{'q(R([-dQ-|(|Q.O)TU.R)U)X5nQ.T)VQ1X-wQ1^-}S1a.S.UQ6X6lQ6[6nQ6]6oQ6r6xR6s6yW'l!d'm(P-^b*k%Y%e*l-l/V0z1_1`5kQ,d'[W-s(o-t-{5SQ.Z)eS/z,W/{Q0Z,lS0^,p0_S1V-u1WQ1[-yQ1e.[Q2l0VQ3u2mQ6Y.cR6q6w'ejOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z0a1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']sOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ+y&tU/m+x+z+{Q/s+|S2^/q/rR2`/t']}Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y^!XOn$h%W%p'y*i&|%^hmo!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(y(|)T)U)V)X)o)v)w*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yQ(_!vQ-g(XQ-o(`R1P-h'e!WOhmno!j!v#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R(X([(`(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-h-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR,X'SQ,W'SR2b/z^!gOn$h%W%p'y*i'S%_hmo!j#Y#Z#[#d#k#l#n#q#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(w(y(|)T)U)V)X)o)v)w*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4y4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yT'U!X!hR-O'sS$gO$hU%on%p'yT*h%W*i_![On$h%W%p'y*iQ'p!eQ(c!wQ(g!yQ*v%iQ*w%mQ+O%uQ,['WQ,_'YQ,h'bQ,j'cQ,s'jQ-T'wS-i(Y(dQ-m([Q.z*gS/S*x*yU0O,Y-U-VQ0S,]S0T,`,aQ0W,eQ0X,gQ0Y,iQ0[,mQ0`,qQ0{-dQ1Q-jQ1S-lQ1T-mQ1z/TU2g0P0Q0lQ2i0UQ2j0VQ2|0zQ2}0{S3p2d2fU3s2k2l2mQ3v2nQ3w2rQ4P3SQ4a3rS4b3t3uQ4d3zQ4n4`R4o4c_!_On$h%W%p'y*i_!`On$h%W%p'y*iq(p#k#l#n%t'Y,a.Z0V1e2l2m3u6q6t6u6vT'[!_!`^!qOn$h%W%p'y*i^%tp!p%g%i%m*g*yT'Z!_!`R'^!_T'`!_!`Q,g'`R,i'bT'b!_!`_!cOn$h%W%p'y*iR'e!_R'h!_S,p'h0aR2p0^^!eOn$h%W%p'y*iR-v(r^!dOn$h%W%p'y*iQ(P!jS(n#d6hS)a$Q4{S)b$S4|S,t'l1VR-u(r_!hOn$h%W%p'y*i_!jOn$h%W%p'y*iR(Q!jY%up!p%g%i*gQ*x%mR/T*y^!rOn$h%W%p'y*i_%tp!p%g%i%m*g*y^!sOn$h%W%p'y*i^%tp!p%g%i%m*g*yR(V!t^!uOn$h%W%p'y*i^%tp!p%g%i%m*g*yR(W!t^!vOn$h%W%p'y*i^%tp!p%g%i%m*g*yR(X!tX0o-_-`0q0uX0s-_-`0q0ug(b!w(Y-a-k-n0x0y0|3P3}4g^#POn$h%W%p'y*iR'x!g_#VOn$h%W%p'y*iV%on%p'yV%mn%p'y!l%yp%Y%e%g(O(k(o)^)d*d+P+Q+T+V+Y+Z+[+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!s5V)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5o5q5s5t5u5x5y5{5|5}6O6P6Q6R6S6T6U6V6^6`6c6p!h&Op%Y%e%g&P(O(k(o)^)d*d+P+Q+V+[+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!o5W)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5X5j5o5q5s5t5u5y5}6O6P6Q6R6S6T6U6V6^6`6c6p!d&Sp%Y%e%g&T(O(k(o)^)d*d+P+Q+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!k5Y)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5Z5j5o5q5s5t5u6O6P6Q6R6S6T6U6V6^6`6c6p!b&`p%Y%e%g(O(k(o)^)d*d+P+Q+]+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!i5`)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5o5q5s5t5u6O6P6Q6R6S6T6U6V6^6`6c6p!^&ap%Y%e%g(O(k(o)d*d+P+Q+^+_+`+a+b+c+d,b-l.}/W/Y0z1_1`1|5S5k6Z!e5a)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p5j5q5s5t5u6P6Q6R6S6T6U6V6^6`6c6pp&gp%Y%e%g(O(o+d,b-l.}0z1_1`5S5k6Zw5g)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p6V6pn&hp%Y%e%g(O(o,b-l.}0z1_1`5S5k6Zu5h)u)|*s+e,O,P,Q,S._.d.f2n3S3V3z4h4p6p%S#ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6f$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k']#cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y%S#lOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6u$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k']#jOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y%S#qOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X4y$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6kT(x#q4yQ(v#qQ-y(wR.c4y%S#uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6i$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6kT)S#u6iW)Q#u(|6i6nR)`$OS)T#u6iT-}(|6n%S#xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6j$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6kT)Y#x6j'[#{Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yT)z$m$|%S$SOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X4|$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k%S$UOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X4}$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k%S$ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V1V1e2l2m3u5n6i6j6l6m6n6o6q6t6u6v6x6y#X6z$l$n%d&j&y&{&}'R)o)v)w0Z1S1[2|4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5w6W6Y6_6e6f6g6h6k']$YOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yT)g$Z6z']$_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']$^Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR)j$_']$dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6y']$cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*i*k+S+f,a-d-s-w-x-}.P.Q.S.U.Z/X0V0Z1S1V1[1e2l2m2|3u4P4d4z4{4|4}5P5Q5T5U5V5W5Y5[5]5^5_5`5a5b5c5d5e5f5g5h5n5w6W6Y6_6e6f6g6h6i6j6k6l6m6n6o6q6t6u6v6x6yR)m$d",
  nodeNames: "⚠ UnrestrictedIdentifier SpecialScalarVariable NamedUnaryOperator ListOperator FileTestOp IOOperatorStart Glob ReadonlySTDIN IOOperatorEnd HeredocStartIdentifier HeredocEndIdentifier InterpolatedStringContent EscapeSequence QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter QuoteLikeEndDelimiter StringContent QWElement RegexOptions PodDirective PodContent PodCut Comment UninterpolatedHeredocBody InterpolatedHeredocBody ScalarVariable ArrayVariable HashVariable PackageVariable PackageName :: Identifier PackageVariableName ] ArrayAccessVariable } HashAccessVariable ArrowOperator { StringSingleQuoted StringQQuoted q StringDoubleQuoted StringQqQuoted qq [ Integer ArithOp Float ScalarDereference $ PackageVariable PackageName PackageVariableName TypeGlob Option HeredocInitializer << SpecialLiteral __FILE__ __LINE__ __PACKAGE__ __SUB__ Pair FatComma ) ( List Comma QWList qw QWListContent ArrayLength $# ArrayRef HashRef ArithOp ArrayAccessVariable HashAccessVariable BacktickQuoted CommandQxQuoted qx PatternMatchM m PatternMatch / RegexQr qr SubstitutionS s TransliterationTrOrY tr y ArrayDereference @ HashDereference % FunctionDereference & TypeGlobDereference * Constant VariableDeclaration our state my local AnonymousFunction sub FunctionPrototype Prototype FunctionAttribute : FunctionSignature ParenthesizedArguments FunctionPrototypeAttribute prototype Block PackageStatement package PackageName Version StatementEnd ; UseNoStatement use no ModuleName Arguments UseNoIfStatement if UseLibStatement lib UseNoSubsStatement subs UseNoFeatureStatement feature UseNoVersion RequireStatement require UseConstantStatement constant UseParentOrBaseStatement parent base NoRequire ExpressionStatement FunctionDefinition async FunctionName SingleLineStatement ReturnExpression return unless while until for foreach IfStatement ElsifClause elsif ElseClause else UnlessStatement WhileStatement Label Continue continue UntilStatement ForStatement1 ForStatement2 \\ StandaloneBlock NamedBlockStatement NamedBlock SpecialBlock BEGIN UNITCHECK CHECK INIT END Ellipsis EmptyStatement PodStatement EndDataStatement __END__ __DATA__ LoopControlStatement next last redo Assignment = UpdateExpression UpdateOp x BinaryExpression ArithOp BindingOp ConcatOp BitOp CompareOp lt gt le ge CompareOp eq ne CompareOp cmp isa BitOp BitOp LogicOp LogicOp RangeOp and or xor UnaryExpression LogicOp RefOp not UpdateExpression ArithOp NoArgumentNamedUnaryOperator fork getpid time times wait wantarray NamedUnaryExpression ListOperatorExpression grep map join sort unpack CallExpression FunctionName CallExpressionWithBareword FunctionName Bless bless OutputFunction print say printf STDIN STDERR STDOUT SystemCall exec system MethodInvocation SUPER FunctionName IndirectMethodInvocation FunctionName CallExpressionRecursive ArrayFunction FunctionName FileTest IOOperator EvalExpression Eval DoExpression do GotoExpression goto TernaryExpression LogicOp ArrayModifierFunction push unshift splice ArrayPopOrShift pop shift HashOrArrayDestructureFunction each values keys Program",
  maxTerm: 455,
  context: contextTracker,
  nodeProps: [
    ["group", -64,2,26,27,28,40,41,43,44,47,49,50,52,55,56,57,59,64,68,70,73,75,76,78,79,80,81,83,85,87,89,91,94,96,98,100,102,103,108,192,194,197,221,225,227,234,235,241,243,245,247,254,257,260,262,263,265,266,267,269,271,273,275,279,282,"Expression",-26,119,125,130,132,134,136,138,139,141,143,147,148,151,159,164,165,169,170,171,173,174,176,182,183,184,185,"Statement"],
    ["closedBy", 6,"IOOperatorEnd",39,"}",46,"]",67,")"],
    ["openedBy", 9,"IOOperatorStart",34,"[",36,"{",66,"("],
    ["isolate", -2,23,40,""]
  ],
  skippedNodes: [0],
  repeatNodeCount: 20,
  tokenData: "!.V~RzXY#uYZ#u]^#upq#uqr#zrs$ast'qtu(Yuv,[vw/xwx1uxy<^yz<cz{<h{|AV|}Bv}!OB{!O!PHj!P!QKd!Q!RKw!R![M_![!]! }!]!^!![!^!_!#R!_!`!#s!`!a!$W!a!b!$p!b!c!$u!c!}!(f!}#O!(w#O#P!)n#P#Q!*g#Q#R!+^#R#S!+i#S#T!,P#T#j!(f#j#k!,U#k#o!(f#o#p!-]#p#q!-b#q#r!-p#r#s!-u~#zO'{~~$PQ%v~!_!`$V#r#s$[~$[O%g~~$aO%_~~$fU(R~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~${UOY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~%bWOY$xZ!O$x!O!P%_!P#d$x#d#e%z#e;'S$x;'S;=`'k<%lO$x~%}WOY$xZ!O$x!O!P%_!P#a$x#a#b&g#b;'S$x;'S;=`'k<%lO$x~&jWOY$xZr$xrs'Ss!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'XU#t~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'nP;=`<%l$x~'vSg~OY'qZ;'S'q;'S;=`(S<%lO'q~(VP;=`<%l'q~(a_#c`!T~st)`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!c!}*Y!}#O)e#O#P)e#P#Q)e#R#S*Y#T#o*Y#o#p*k~)eO!l~`)jY#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~*_Sj~!Q![*Y!c!}*Y#R#S*Y#T#o*Y~*nVXY*kYZ*k]^*kpq*k!c!}+T#R#S+T#T#o+T~+WXXY+sYZ+s]^+spq+s!Q![+T!c!}+T#R#S+T#T#o+T#q#r,V~+vTXY+sYZ+s]^+spq+s#q#r,V~,[Oj~~,ca#c`#T~qr-htu)euv)evw)ez{)e{|-m}!O-h!Q![.d!]!^)e!_!`.u!b!c)e!c!}.d!}#O)e#O#P.z#P#Q)e#R#S.d#T#o.d~-mOl~~-tYl~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~.iSl~!Q![.d!c!}.d#R#S.d#T#o.d~.zO%Z~~/PZ#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R/r~/uP!c!}-h~0P[#c`#V~tu)euv)evw0uz{)e{|)e!O!P1o!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~0|Z%oQ#c`tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~1rP!_!`.u~1zZx~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~2rVx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X<%lO2m~3^Ox~~3aRO;'S2m;'S;=`3j;=`O2m~3oWx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l2m<%lO2m~4[P;=`<%l2m~4dUx~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~4yUOY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~5`WOY4vZ!O4v!O!P5]!P#d4v#d#e5x#e;'S4v;'S;=`7i<%lO4v~5{WOY4vZ!O4v!O!P5]!P#a4v#a#b6e#b;'S4v;'S;=`7i<%lO4v~6hWOY4vZw4vwx7Qx!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7VU#t~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7lP;=`<%l4v~7t]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#d1u#d#e9w#e;'S1u;'S;=`<W<%lO1u~8pWOY1uYZ2mZ!O1u!O!P7o!P;'S1u;'S;=`9Y;=`<%l2m<%lO1u~9_Wx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l1u<%lO2m~9|]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#a1u#a#b:u#b;'S1u;'S;=`<W<%lO1u~:zZx~OY1uYZ2mZw1uwx;mx!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~;tU#t~x~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~<ZP;=`<%l1u~<cO!e~~<hO!d~~<o_#c`#X~tu)euv)evw)ez{=n{|)e!]!^)e!_!`.u!b!c)e!c!}>h!}#O)e#O#P)e#P#Q)e#R#S>h#T#o>h#o#p?c~=uZ#c`%^~tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~>mT!X~!Q![>h![!]>|!c!}>h#R#S>h#T#o>h~?PP![!]?S~?VS!c!}>h#R#S>h#T#o>h#o#p?c~?fVXY?cYZ?c]^?cpq?c!c!}?{#R#S?{#T#o?{~@OXXY@kYZ@k]^@kpq@k!Q![?{!c!}?{#R#S?{#T#o?{#q#r@}~@nTXY@kYZ@k]^@kpq@k#q#r@}~ASP!X~![!]>|~A^Z#c`!o~tu)euv)evw)ez{)e{|BP!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~BWY#c`%z~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~B{O!g~~CQW!Qk}!OCj!_!`.u!`!aCo!c!}Ct#R#SCt#T#bCt#b#cDV#c#oCt~CoO%z~~CtOv~kCyS!Yk!Q![Ct!c!}Ct#R#SCt#T#oCtoD[U!Yk!Q![Ct!c!}Ct#R#SCt#T#cCt#c#dDn#d#oCtoDsU!Yk!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gEV#g#oCtoE[U!Yk!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YEn#Y#oCtoEsU!Yk!Q![Ct!c!}Ct#R#SCt#T#eCt#e#fFV#f#oCtoF[U!Yk!Q![Ct!c!}Ct#R#SCt#T#iCt#i#jFn#j#oCtoFsU!Yk!Q![Ct!c!}Ct#R#SCt#T#]Ct#]#^GV#^#oCtoG[U!Yk!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gGn#g#oCtoGsU!Yk!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YHV#Y#oCtoH^S$WS!Yk!Q![Ct!c!}Ct#R#SCt#T#oCt~HqS#n[%`Q!O!PH}!Q![JP!_!`.u#R#SIq_IUR%qQ#n[!O!PI_!Q![Iq#R#SIq_IhR)hP%qQ#n[!O!PIq!Q![Iq#R#SIq[IvR#n[!O!PIq!Q![Iq#R#SIq~JWT#n[!R~!O!PIq!Q![JP!g!hJg#R#SKU#X#YJg~JjR{|Js}!OJs!Q![Jy~JvP!Q![Jy~KOQ!R~!Q![Jy#R#SJs~KZR#n[!O!PIq!Q![JP#R#SIq~KiQ!x~!P!QKo!_!`.u~KtP%p~!_!`.u~LO[#n[!P~!O!PJP!Q!YLt!Y![M_!d!eNf!g!hJg!q!rN}!z!{! `#R#SMu#U#VNf#X#YJg#c#dN}#l#m! `~L{U#n[!P~!O!PJP!Q!YLt!Y![M_!g!hJg#R#SNT#X#YJg~MfT#n[!P~!O!PJP!Q![M_!g!hJg#R#SMu#X#YJg~MzR#n[!O!PIq!Q![M_#R#SIq~NYS#n[!O!PIq!Q!YLt!Y![M_#R#SIq~NiQ!Q!RNo!R!SNo~NtR!P~!Q!RNo!R!SNo#R#SNf~! QP!Q!Y! T~! YQ!P~!Q!Y! T#R#SN}~! cR!Q![! l!c!i! l#T#Z! l~! qS!P~!Q![! l!c!i! l#R#S! `#T#Z! l~!!SP#e~![!]!!V~!![Oo~o!!cY#p_#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!#WQ%b~!^!_!#^!_!`!#f~!#cP![~!_!`.u~!#kP%b~!`!a!#n~!#sO%j~~!#xR%X~!_!`$V!`!a!$R#r#s$[~!$WO!c~~!$]Q%b~!_!`!$c!`!a!$h~!$hO%b~~!$mP%a~!_!`.u~!$uO&|~~!$|c#c`#R~qr!&Xtu)euv)evw)ez{)e{|!&^|!Q!&X!Q![!'T![!]!&X!]!^!&^!^!b!&X!b!c!&^!c!}!'T!}#O!&^#O#P!'f#P#Q!&^#Q#R!&X#R#S!'T#T#o!'T~!&^Ok~~!&eYk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!'YSk~!Q![!'T!c!}!'T#R#S!'T#T#o!'T~!'mZk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R!(`~!(cP!c!}!&X~!(kSp~!Q![!(f!c!}!(f#R#S!(f#T#o!(f~!)OY#c`!O~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)eo!)wY$rS%wk#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)ec!*nYrR#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!+cQ%n~!O!P1o!_!`.u~!+pT#n[p~!O!PIq!Q![!+i!c!}!(f#R#S!+i#T#o!(f~!,UO(`~~!,ZTp~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f[!,oQ#n[!O!P!,j!Q![!,j~!,|T#n[p~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f~!-bOw~~!-gR%n~!O!P1o!_!`.u#p#qKo~!-uOt~~!-zQ%v~!O!P!.Q#r#s!#n~!.VO%v~",
  tokenizers: [semicolon, unrestrictedIdentifier, specialScalarVariable, builtinOperator, fileIO, heredoc, interpolated, quoteLikeOperator, regex, pod, endData, 0, 1, 2, 3, 4],
  topRules: {"Program":[0,286]},
  dynamicPrecedences: {"152":1,"185":4,"268":1,"321":1,"323":1,"326":1,"330":1,"331":1,"332":1,"333":1,"337":1,"339":1,"340":1,"341":1,"342":1,"344":1,"345":1,"347":1,"348":1,"349":1,"350":1,"353":1,"354":1,"356":1,"358":1,"359":1,"362":1,"363":1,"364":1,"366":1,"367":1,"368":1,"369":1,"370":1,"375":1,"376":1,"379":1,"380":1,"381":1,"382":1,"383":1,"384":1,"385":1,"386":1,"387":1,"388":1,"389":1,"390":1,"391":1,"393":1,"394":1,"396":1,"397":1,"398":1,"399":1,"400":1,"401":1,"402":1,"403":1,"404":1,"405":1,"406":1,"407":1,"408":1,"409":1,"410":1,"411":1,"412":1,"413":1,"414":1,"415":1,"416":1,"417":1,"419":1,"420":1,"421":1,"422":1,"423":1,"424":1,"427":1,"428":1,"429":1,"431":1,"432":1,"433":1,"435":1,"436":1,"438":1,"440":1,"441":1,"442":1,"443":1,"444":1,"445":1,"447":1,"448":1,"449":1,"451":1,"452":1,"453":1,"454":1},
  specialized: [{term: 32, get: (value) => spec_Identifier[value] || -1}],
  tokenPrec: 28155
});

const perlLanguage = language.LRLanguage.define({
    name: 'perl',
    parser: parser.configure({
        props: [
            language.indentNodeProp.add({
                IfStatement: language.continuedIndent({ except: /^\s*({|else\b|elsif\b)/ }),
                Block: language.delimitedIndent({ closing: '}' }),
                String: () => null,
                Statement: language.continuedIndent()
            }),
            language.foldNodeProp.add({
                'Block Array ArrayRef HashRef': language.foldInside,
                'InterpolatedHeredocBody UninterpolatedHeredocBody': (node) => {
                    if (node.prevSibling && node.lastChild)
                        return { from: node.prevSibling.to, to: node.lastChild.from };
                    return null;
                },
                PodStatement(node) {
                    if (node.firstChild?.type.name === 'PodDirective' &&
                        node.firstChild.nextSibling?.type.name === 'PodContent')
                        return { from: node.firstChild.nextSibling.from, to: node.firstChild.nextSibling.to };
                    return null;
                },
                EndDataStatement: (node) => (node.firstChild ? { from: node.firstChild.to, to: node.to } : null)
            }),
            highlight.styleTags({
                'do continue else elsif for foreach goto if last next redo return unless until when while': highlight.tags.controlKeyword,
                'bless local my our state sub': highlight.tags.definitionKeyword,
                'package use no import require parent base': highlight.tags.moduleKeyword,
                'constant feature lib subs async prototype': highlight.tags.modifier,
                'NamedUnaryOperator ListOperator Eval each exec fork getpid grep': highlight.tags.function(highlight.tags.keyword),
                'join keys map pop print printf push say shift sort splice system time times': highlight.tags.function(highlight.tags.keyword),
                'unpack unshift values wait wantarray': highlight.tags.function(highlight.tags.keyword),
                'BEGIN CHECK END INIT UNITCHECK': highlight.tags.processingInstruction,
                '__FILE__ __LINE__ __PACKAGE__ __SUB__': highlight.tags.literal,
                'ScalarVariable SpecialScalarVariable ArrayVariable HashVariable': highlight.tags.variableName,
                'ArrayLength/Identifier Prototype Constant/Identifier': highlight.tags.variableName,
                'PackageVariable/PackageVariableName/...': highlight.tags.variableName,
                'PackageName/Identifier PackageName/UnrestrictedIdentifier PackageName/ScalarVariable': highlight.tags.namespace,
                'PackageName/ArrayVariable PackageName/HashVariable SUPER': highlight.tags.namespace,
                'NamedType/...': highlight.tags.typeName,
                Name: highlight.tags.name,
                'Label/Identifier LabelName/Identifier STDIN STDERR STDOUT IOOperator/Identifier': highlight.tags.labelName,
                'MemberExpression/Identifier': highlight.tags.propertyName,
                'MemberExpression/ScalarVariable': highlight.tags.special(highlight.tags.propertyName),
                'FunctionName/PackageName/... FunctionName/Identifier': highlight.tags.function(highlight.tags.definition(highlight.tags.variableName)),
                UpdateOp: highlight.tags.updateOperator,
                'ArithOp "*" % "/"': highlight.tags.arithmeticOperator,
                'LogicOp and not or xor : FileTestOp': highlight.tags.logicOperator,
                BitOp: highlight.tags.bitwiseOperator,
                '<<': highlight.tags.special(highlight.tags.bitwiseOperator),
                'CompareOp < lt gt le ge eq ne cmp isa': highlight.tags.compareOperator,
                '=': highlight.tags.definitionOperator,
                '$ $# @ % & "*" ArrowOperator \\': highlight.tags.derefOperator,
                'ScalarDereference/{ ScalarDereference/}': highlight.tags.derefOperator,
                'ArrayDereference/{ ArrayDereference/}': highlight.tags.derefOperator,
                'HashDereference/{ HashDereference/}': highlight.tags.derefOperator,
                'FunctionDereference/{ FunctionDereference/}': highlight.tags.derefOperator,
                'TypeGlobDereference/{ TypeGlobDereference/}': highlight.tags.derefOperator,
                'ConcatOp BindingOp RangeOp RefOp x': highlight.tags.operator,
                Comment: highlight.tags.lineComment,
                Integer: highlight.tags.integer,
                Float: highlight.tags.float,
                'StringSingleQuoted StringDoubleQuoted q qq qx */StringContent */InterpolatedStringContent': highlight.tags.string,
                '*/QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter */QuoteLikeEndDelimiter': highlight.tags.string,
                'qw QWListContent/... Pair/Identifier HashAccessVariable/Identifier Version': highlight.tags.string,
                'HeredocInitializer/... HeredocEndIdentifier Glob': highlight.tags.string,
                'm qr s tr y RegexOptions': highlight.tags.special(highlight.tags.string),
                'PodStatement EndDataStatement/...': highlight.tags.blockComment,
                EscapeSequence: highlight.tags.escape,
                'Comma FatComma': highlight.tags.punctuation,
                '( )': highlight.tags.paren,
                '[ ]': highlight.tags.squareBracket,
                '{ }': highlight.tags.brace,
                '; :: :': highlight.tags.separator
            })
        ]
    }),
    languageData: { commentTokens: { line: '#' } }
});
const perlCompletion = perlLanguage.data.of({
    autocomplete: autocomplete.completeFromList([
        { label: 'my', type: 'keyword' },
        { label: 'use', type: 'keyword' },
        { label: 'sub', type: 'keyword' }
    ])
});
const perl = () => new language.LanguageSupport(perlLanguage, [perlCompletion]);

exports.perl = perl;
exports.perlCompletion = perlCompletion;
exports.perlLanguage = perlLanguage;
